"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6.QtOpenGL import *
import enum


class QOpenGLWindow(QtGui.QPaintDeviceWindow):
    """
    https://doc.qt.io/qt-6/qopenglwindow.html

    **Detailed Description**

    QOpenGLWindow is an enhanced **QWindow**  that allows easily creating
    windows that perform OpenGL rendering using an API that is compatible with
    **QOpenGLWidget**  Unlike **QOpenGLWidget** , QOpenGLWindow has no
    dependency on the widgets module and offers better performance.

    A typical application will subclass QOpenGLWindow and reimplement the
    following virtual functions:

    * **initializeGL** () to perform OpenGL resource initialization
      *
    **resizeGL** () to set up the transformation matrices and other window size
    dependent resources
      * **paintGL** () to issue OpenGL commands or draw
    using **QPainter**

    To schedule a repaint, call the **update** () function. Note that this will
    not immediately result in a call to **paintGL** (). Calling **update** ()
    multiple times in a row will not change the behavior in any way.

    This is a slot so it can be connected to a **QTimer::timeout** () signal to
    perform animation. Note however that in the modern OpenGL world it is a much
    better choice to rely on synchronization to the vertical refresh rate of the
    display. See **setSwapInterval** () on a description of the swap interval.
    With a swap interval of `1`, which is the case on most systems by default,
    the **swapBuffers** () call, that is executed internally by QOpenGLWindow
    after each repaint, will block and wait for vsync. This means that whenever
    the swap is done, an update can be scheduled again by calling **update** (),
    without relying on timers.

    To request a specific configuration for the context, use **setFormat** ()
    like for any other **QWindow** . This allows, among others, requesting a
    given OpenGL version and profile, or enabling depth and stencil buffers.

    Unlike **QWindow** , QOpenGLWindow allows opening a painter on itself and
    perform **QPainter** -based drawing.

    QOpenGLWindow supports multiple update behaviors. The default,
    `NoPartialUpdate` is equivalent to a regular, OpenGL-based **QWindow** . In
    contrast, `PartialUpdateBlit` and `PartialUpdateBlend` are more in line with
    **QOpenGLWidget** 's way of working, where there is always an extra,
    dedicated framebuffer object present. These modes allow, by sacrificing some
    performance, redrawing only a smaller area on each paint and having the rest
    of the content preserved from of the previous frame. This is useful for
    applications than render incrementally using **QPainter** , because this way
    they do not have to redraw the entire window content on each **paintGL** ()
    call.

    Similarly to **QOpenGLWidget** , QOpenGLWindow supports the
    **Qt::AA_ShareOpenGLContexts**  attribute. When enabled, the OpenGL contexts
    of all QOpenGLWindow instances will share with each other. This allows
    accessing each other's shareable OpenGL resources.

    For more information on graphics in Qt, see **Graphics** .
    """

    class UpdateBehavior(enum.Enum):
        NoPartialUpdate: QOpenGLWindow = ...
        PartialUpdateBlit: QOpenGLWindow = ...
        PartialUpdateBlend: QOpenGLWindow = ...

    @typing.overload
    def __init__(
        self,
        updateBehavior: "QOpenGLWindow.UpdateBehavior" = ...,
        parent: typing.Optional[QtGui.QWindow] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopenglwindow.html#QOpenGLWindow

        **QOpenGLWindow::QOpenGLWindow(QOpenGLWindow::UpdateBehavior
        updateBehavior = NoPartialUpdate, QWindow * parent = nullptr)**

        Constructs a new QOpenGLWindow with the given **parent** and
        **updateBehavior**.

        **See also** **QOpenGLWindow::UpdateBehavior** .
        """
        ...

    @typing.overload
    def __init__(
        self,
        shareContext: QtGui.QOpenGLContext,
        updateBehavior: "QOpenGLWindow.UpdateBehavior" = ...,
        parent: typing.Optional[QtGui.QWindow] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopenglwindow.html#QOpenGLWindow-1

        **QOpenGLWindow::QOpenGLWindow(QOpenGLContext * shareContext ,
        QOpenGLWindow::UpdateBehavior updateBehavior = NoPartialUpdate, QWindow
        * parent = nullptr)**

        Constructs a new QOpenGLWindow with the given **parent** and
        **updateBehavior**. The QOpenGLWindow's context will share with
        **shareContext**.

        **See also** **QOpenGLWindow::UpdateBehavior**  and **shareContext** .
        """
        ...

    def metric(self, metric: QtGui.QPaintDevice.PaintDeviceMetric) -> int:
        ...

    def resizeEvent(self, event: QtGui.QResizeEvent) -> None:
        """
        https://doc.qt.io/qt-6/qopenglwindow.html#resizeEvent

        **[override virtual protected] void
        QOpenGLWindow::resizeEvent(QResizeEvent * event )**

        Reimplements: **QWindow::resizeEvent** (QResizeEvent *ev).

        Resize **event** handler. Calls **resizeGL** ().

        **See also** **resizeGL** ().
        """
        ...

    def paintEvent(self, event: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qopenglwindow.html#paintEvent

        **[override virtual protected] void
        QOpenGLWindow::paintEvent(QPaintEvent * event )**

        Reimplements: **QPaintDeviceWindow::paintEvent** (QPaintEvent *event).

        Paint **event** handler. Calls **paintGL** ().

        **See also** **paintGL** ().
        """
        ...

    def paintOverGL(self) -> None:
        """
        https://doc.qt.io/qt-6/qopenglwindow.html#paintOverGL

        **[virtual protected] void QOpenGLWindow::paintOverGL()**

        This virtual function is called after each invocation of **paintGL** ().

        When the update mode is set to **NoPartialUpdate** , there is no
        difference between this function and **paintGL** (), performing
        rendering in either of them leads to the same result.

        Like **paintUnderGL** (), rendering in this function targets the default
        framebuffer of the window, regardless of the update behavior. It gets
        called after **paintGL** () has returned and the blit
        (**PartialUpdateBlit** ) or quad drawing (**PartialUpdateBlend** ) has
        been done.

        **See also** **paintGL** (), **paintUnderGL** (), and **UpdateBehavior**
        .
        """
        ...

    def paintUnderGL(self) -> None:
        """
        https://doc.qt.io/qt-6/qopenglwindow.html#paintUnderGL

        **[virtual protected] void QOpenGLWindow::paintUnderGL()**

        The virtual function is called before each invocation of **paintGL** ().

        When the update mode is set to `NoPartialUpdate`, there is no difference
        between this function and **paintGL** (), performing rendering in either
        of them leads to the same result.

        The difference becomes significant when using `PartialUpdateBlend`,
        where an extra framebuffer object is used. There, **paintGL** () targets
        this additional framebuffer object, which preserves its contents, while
        paintUnderGL() and **paintOverGL** () target the default framebuffer,
        i.e. directly the window surface, the contents of which is lost after
        each displayed frame.

        **Note:** Avoid relying on this function when the update behavior is
        `PartialUpdateBlit`. This mode involves blitting the extra framebuffer
        used by **paintGL** () onto the default framebuffer after each
        invocation of **paintGL** (), thus overwriting all drawing generated in
        this function.

        **See also** **paintGL** (), **paintOverGL** (), and **UpdateBehavior**
        .
        """
        ...

    def paintGL(self) -> None:
        """
        https://doc.qt.io/qt-6/qopenglwindow.html#paintGL

        **[virtual protected] void QOpenGLWindow::paintGL()**

        This virtual function is called whenever the window contents needs to be
        painted. Reimplement it in a subclass.

        There is no need to call **makeCurrent** () because this has already
        been done when this function is called.

        Before invoking this function, the context and the framebuffer, if there
        is one, are bound, and the viewport is set up by a call to glViewport().
        No other state is set and no clearing or drawing is performed by the
        framework.

        **Note:** When using a partial update behavior, like
        `PartialUpdateBlend`, the output of the previous paintGL() call is
        preserved and, after the additional drawing perfomed in the current
        invocation of the function, the content is blitted or blended over the
        content drawn directly to the window in **paintUnderGL** ().

        **See also** **initializeGL** (), **resizeGL** (), **paintUnderGL** (),
        **paintOverGL** (), and **UpdateBehavior** .
        """
        ...

    def resizeGL(self, w: int, h: int) -> None:
        """
        https://doc.qt.io/qt-6/qopenglwindow.html#resizeGL

        **[virtual protected] void QOpenGLWindow::resizeGL(int w , int h )**

        This virtual function is called whenever the widget has been resized.
        Reimplement it in a subclass. The new size is passed in **w** and **h**.

        **Note:** This is merely a convenience function in order to provide an
        API that is compatible with **QOpenGLWidget** . Unlike with
        **QOpenGLWidget** , derived classes are free to choose to override
        **resizeEvent** () instead of this function.

        **Note:** Avoid issuing OpenGL commands from this function as there may
        not be a context current when it is invoked. If it cannot be avoided,
        call **makeCurrent** ().

        **Note:** Scheduling updates from here is not necessary. The windowing
        systems will send expose events that trigger an update automatically.

        **See also** **initializeGL** () and **paintGL** ().
        """
        ...

    def initializeGL(self) -> None:
        """
        https://doc.qt.io/qt-6/qopenglwindow.html#initializeGL

        **[virtual protected] void QOpenGLWindow::initializeGL()**

        This virtual function is called once before the first call to
        **paintGL** () or **resizeGL** (). Reimplement it in a subclass.

        This function should set up any required OpenGL resources and state.

        There is no need to call **makeCurrent** () because this has already
        been done when this function is called. Note however that the
        framebuffer, in case partial update mode is used, is not yet available
        at this stage, so avoid issuing draw calls from here. Defer such calls
        to **paintGL** () instead.

        **See also** **paintGL** () and **resizeGL** ().
        """
        ...

    def shareContext(self) -> QtGui.QOpenGLContext:
        """
        https://doc.qt.io/qt-6/qopenglwindow.html#shareContext

        **QOpenGLContext *QOpenGLWindow::shareContext() const**

        Returns The **QOpenGLContext**  requested to be shared with this
        window's **QOpenGLContext** .
        """
        ...

    def grabFramebuffer(self) -> QtGui.QImage:
        """
        https://doc.qt.io/qt-6/qopenglwindow.html#grabFramebuffer

        **QImage QOpenGLWindow::grabFramebuffer()**

        Returns a copy of the framebuffer.

        **Note:** This is a potentially expensive operation because it relies on
        glReadPixels() to read back the pixels. This may be slow and can stall
        the GPU pipeline.

        **Note:** When used together with update behavior `NoPartialUpdate`, the
        returned image may not contain the desired content when called after the
        front and back buffers have been swapped (unless preserved swap is
        enabled in the underlying windowing system interface). In this mode the
        function reads from the back buffer and the contents of that may not
        match the content on the screen (the front buffer). In this case the
        only place where this function can safely be used is **paintGL** () or
        **paintOverGL** ().
        """
        ...

    def defaultFramebufferObject(self) -> int:
        """
        https://doc.qt.io/qt-6/qopenglwindow.html#defaultFramebufferObject

        **GLuint QOpenGLWindow::defaultFramebufferObject() const**

        The framebuffer object handle used by this window.

        When the update behavior is set to `NoPartialUpdate`, there is no
        separate framebuffer object. In this case the returned value is the ID
        of the default framebuffer.

        Otherwise the value of the ID of the framebuffer object or `0` if not
        yet initialized.
        """
        ...

    def context(self) -> QtGui.QOpenGLContext:
        """
        https://doc.qt.io/qt-6/qopenglwindow.html#context

        **QOpenGLContext *QOpenGLWindow::context() const**

        Returns The **QOpenGLContext**  used by this window or `0` if not yet
        initialized.
        """
        ...

    def doneCurrent(self) -> None:
        """
        https://doc.qt.io/qt-6/qopenglwindow.html#doneCurrent

        **void QOpenGLWindow::doneCurrent()**

        Releases the context.

        It is not necessary to call this function in most cases, since the
        widget will make sure the context is bound and released properly when
        invoking **paintGL** ().

        **See also** **makeCurrent** ().
        """
        ...

    def makeCurrent(self) -> None:
        """
        https://doc.qt.io/qt-6/qopenglwindow.html#makeCurrent

        **void QOpenGLWindow::makeCurrent()**

        Prepares for rendering OpenGL content for this window by making the
        corresponding context current and binding the framebuffer object, if
        there is one, in that context context.

        It is not necessary to call this function in most cases, because it is
        called automatically before invoking **paintGL** (). It is provided
        nonetheless to support advanced, multi-threaded scenarios where a thread
        different than the GUI or main thread may want to update the surface or
        framebuffer contents. See **QOpenGLContext**  for more information on
        threading related issues.

        This function is suitable for calling also when the underlying platform
        window is already destroyed. This means that it is safe to call this
        function from a **QOpenGLWindow**  subclass' destructor. If there is no
        native window anymore, an offscreen surface is used instead. This
        ensures that OpenGL resource cleanup operations in the destructor will
        always work, as long as this function is called first.

        **See also** **QOpenGLContext** , **context** (), **paintGL** (), and
        **doneCurrent** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglwindow.html#isValid

        **bool QOpenGLWindow::isValid() const**

        Returns `true` if the window's OpenGL resources, like the context, have
        been successfully initialized. Note that the return value is always
        `false` until the window becomes exposed (shown).
        """
        ...

    def updateBehavior(self) -> "QOpenGLWindow.UpdateBehavior":
        """
        https://doc.qt.io/qt-6/qopenglwindow.html#updateBehavior

        **QOpenGLWindow::UpdateBehavior QOpenGLWindow::updateBehavior() const**

        Returns the update behavior for this **QOpenGLWindow** .
        """
        ...

    @property
    def frameSwapped(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qopenglwindow.html#frameSwapped

        **[signal] void QOpenGLWindow::frameSwapped()**

        This signal is emitted after the potentially blocking **buffer swap**
        has been done. Applications that wish to continuously repaint
        synchronized to the vertical refresh, should issue an **update** () upon
        this signal. This allows for a much smoother experience compared to the
        traditional usage of timers.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QTableWidgetItem(PyQt6.sip.wrapper):
    """
    https://doc.qt.io/qt-6/qtablewidgetitem.html

    **Detailed Description**

    Table items are used to hold pieces of information for table widgets. Items
    usually contain text, icons, or checkboxes

    The QTableWidgetItem class is a convenience class that replaces the
    `QTableItem` class in Qt 3. It provides an item for use with the
    **QTableWidget**  class.

    Top-level items are constructed without a parent then inserted at the
    position specified by a pair of row and column numbers:

    **QTableWidgetItem**  *newItem = new **QTableWidgetItem** (tr("%1").arg(
    pow(row, column+1)));
            tableWidget->setItem(row, column, newItem);

    Each item can have its own background brush which is set with the
    **setBackground** () function. The current background brush can be found
    with **background** (). The text label for each item can be rendered with
    its own font and brush. These are specified with the **setFont** () and
    **setForeground** () functions, and read with **font** () and **foreground**
    ().

    By default, items are enabled, editable, selectable, checkable, and can be
    used both as the source of a drag and drop operation and as a drop target.
    Each item's flags can be changed by calling **setFlags** () with the
    appropriate value (see **Qt::ItemFlags** ). Checkable items can be checked
    and unchecked with the **setCheckState** () function. The corresponding
    **checkState** () function indicates whether the item is currently checked.

    **Subclassing**

    When subclassing QTableWidgetItem to provide custom items, it is possible to
    define new types for them so that they can be distinguished from standard
    items. The constructors for subclasses that require this feature need to
    call the base class constructor with a new type value equal to or greater
    than **UserType** .

    **See also** **QTableWidget** , **Model/View Programming** ,
    **QListWidgetItem** , and **QTreeWidgetItem** .
    """

    class ItemType(enum.Enum):
        Type: QTableWidgetItem = ...
        UserType: QTableWidgetItem = ...

    @typing.overload
    def __init__(self, type: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#QTableWidgetItem

        **QTableWidgetItem::QTableWidgetItem(int type = Type)**

        Constructs a table item of the specified **type** that does not belong
        to any table.

        **See also** **type** ().
        """
        ...

    @typing.overload
    def __init__(self, text: str, type: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#QTableWidgetItem-1

        **QTableWidgetItem::QTableWidgetItem(const QString & text , int type =
        Type)**

        Constructs a table item with the given **text**.

        **See also** **type** ().
        """
        ...

    @typing.overload
    def __init__(self, icon: QtGui.QIcon, text: str, type: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#QTableWidgetItem-2

        **QTableWidgetItem::QTableWidgetItem(const QIcon & icon , const QString
        & text , int type = Type)**

        Constructs a table item with the given **icon** and **text**.

        **See also** **type** ().
        """
        ...

    @typing.overload
    def __init__(self, other: "QTableWidgetItem") -> None:
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#QTableWidgetItem-3

        **QTableWidgetItem::QTableWidgetItem(const QTableWidgetItem & other )**

        Constructs a copy of **other**. Note that **type** () and
        **tableWidget** () are not copied.

        This function is useful when reimplementing **clone** ().

        **See also** **data** () and **flags** ().
        """
        ...

    def isSelected(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#isSelected

        **bool QTableWidgetItem::isSelected() const**

        Returns `true` if the item is selected, otherwise returns `false`.

        **See also** **setSelected** ().
        """
        ...

    def setSelected(self, aselect: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#setSelected

        **void QTableWidgetItem::setSelected(bool select )**

        Sets the selected state of the item to **select**.

        **See also** **isSelected** ().
        """
        ...

    def column(self) -> int:
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#column

        **int QTableWidgetItem::column() const**

        Returns the column of the item in the table. If the item is not in a
        table, this function will return -1.

        **See also** **row** ().
        """
        ...

    def row(self) -> int:
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#row

        **int QTableWidgetItem::row() const**

        Returns the row of the item in the table. If the item is not in a table,
        this function will return -1.

        **See also** **column** ().
        """
        ...

    def setForeground(
        self,
        brush: typing.Union[
            QtGui.QBrush, QtGui.QColor, QtCore.Qt.GlobalColor, int, QtGui.QGradient
        ],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#setForeground

        **void QTableWidgetItem::setForeground(const QBrush & brush )**

        Sets the item's foreground brush to the specified **brush**. Setting a
        default-constructed brush will let the view use the default color from
        the style.

        **See also** **foreground** () and **setBackground** ().
        """
        ...

    def foreground(self) -> QtGui.QBrush:
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#foreground

        **QBrush QTableWidgetItem::foreground() const**

        Returns the brush used to render the item's foreground (e.g. text).

        **See also** **setForeground** () and **background** ().
        """
        ...

    def setBackground(
        self,
        brush: typing.Union[
            QtGui.QBrush, QtGui.QColor, QtCore.Qt.GlobalColor, int, QtGui.QGradient
        ],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#setBackground

        **void QTableWidgetItem::setBackground(const QBrush & brush )**

        Sets the item's background brush to the specified **brush**. Setting a
        default-constructed brush will let the view use the default color from
        the style.

        **See also** **background** () and **setForeground** ().
        """
        ...

    def background(self) -> QtGui.QBrush:
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#background

        **QBrush QTableWidgetItem::background() const**

        Returns the brush used to render the item's background.

        **See also** **setBackground** () and **foreground** ().
        """
        ...

    def setSizeHint(self, size: QtCore.QSize) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#setSizeHint

        **void QTableWidgetItem::setSizeHint(const QSize & size )**

        Sets the size hint for the table item to be **size**. If no size hint is
        set or **size** is invalid, the item delegate will compute the size hint
        based on the item data.

        **See also** **sizeHint** ().
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#sizeHint

        **QSize QTableWidgetItem::sizeHint() const**

        Returns the size hint set for the table item.

        **See also** **setSizeHint** ().
        """
        ...

    def setFont(self, afont: QtGui.QFont) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#setFont

        **void QTableWidgetItem::setFont(const QFont & font )**

        Sets the font used to display the item's text to the given **font**.

        **See also** **font** (), **setText** (), and **setForeground** ().
        """
        ...

    def setWhatsThis(self, awhatsThis: str) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#setWhatsThis

        **void QTableWidgetItem::setWhatsThis(const QString & whatsThis )**

        Sets the item's "What's This?" help to the string specified by
        **whatsThis**.

        **See also** **whatsThis** (), **setStatusTip** (), and **setToolTip**
        ().
        """
        ...

    def setToolTip(self, atoolTip: str) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#setToolTip

        **void QTableWidgetItem::setToolTip(const QString & toolTip )**

        Sets the item's tooltip to the string specified by **toolTip**.

        **See also** **toolTip** (), **setStatusTip** (), and **setWhatsThis**
        ().
        """
        ...

    def setStatusTip(self, astatusTip: str) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#setStatusTip

        **void QTableWidgetItem::setStatusTip(const QString & statusTip )**

        Sets the status tip for the table item to the text specified by
        **statusTip**. **QTableWidget**  mouse tracking needs to be enabled for
        this feature to work.

        **See also** **statusTip** (), **setToolTip** (), and **setWhatsThis**
        ().
        """
        ...

    def setIcon(self, aicon: QtGui.QIcon) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#setIcon

        **void QTableWidgetItem::setIcon(const QIcon & icon )**

        Sets the item's icon to the **icon** specified.

        **See also** **icon** (), **setText** (), and **iconSize** .
        """
        ...

    def setText(self, atext: str) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#setText

        **void QTableWidgetItem::setText(const QString & text )**

        Sets the item's text to the **text** specified.

        **See also** **text** (), **setFont** (), and **setForeground** ().
        """
        ...

    def setFlags(self, aflags: QtCore.Qt.ItemFlag) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#setFlags

        **void QTableWidgetItem::setFlags(Qt::ItemFlags flags )**

        Sets the flags for the item to the given **flags**. These determine
        whether the item can be selected or modified.

        **See also** **flags** ().
        """
        ...

    def type(self) -> int:
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#type

        **int QTableWidgetItem::type() const**

        Returns the type passed to the **QTableWidgetItem**  constructor.
        """
        ...

    def write(self, out: QtCore.QDataStream) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#write

        **[virtual] void QTableWidgetItem::write(QDataStream & out ) const**

        Writes the item to stream **out**.

        **See also** **read** ().
        """
        ...

    def read(self, in_: QtCore.QDataStream) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#read

        **[virtual] void QTableWidgetItem::read(QDataStream & in )**

        Reads the item from stream **in**.

        **See also** **write** ().
        """
        ...

    def setData(self, role: int, value: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#setData

        **[virtual] void QTableWidgetItem::setData(int role , const QVariant &
        value )**

        Sets the item's data for the given **role** to the specified **value**.

        **Note:** The default implementation treats **Qt::EditRole**  and
        **Qt::DisplayRole**  as referring to the same data.

        **See also** **Qt::ItemDataRole**  and **data** ().
        """
        ...

    def data(self, role: int) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#data

        **[virtual] QVariant QTableWidgetItem::data(int role ) const**

        Returns the item's data for the given **role**.

        **See also** **setData** ().
        """
        ...

    def setCheckState(self, state: QtCore.Qt.CheckState) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#setCheckState

        **void QTableWidgetItem::setCheckState(Qt::CheckState state )**

        Sets the check state of the table item to be **state**.

        **See also** **checkState** ().
        """
        ...

    def checkState(self) -> QtCore.Qt.CheckState:
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#checkState

        **Qt::CheckState QTableWidgetItem::checkState() const**

        Returns the checked state of the table item.

        **See also** **setCheckState** () and **flags** ().
        """
        ...

    def setTextAlignment(self, alignment: int) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#setTextAlignment

        **void QTableWidgetItem::setTextAlignment(int alignment )**

        Sets the text alignment for the item's text to the **alignment**
        specified.

        **See also** **textAlignment** () and **Qt::Alignment** .
        """
        ...

    def textAlignment(self) -> int:
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#textAlignment

        **int QTableWidgetItem::textAlignment() const**

        Returns the text alignment for the item's text.

        **See also** **setTextAlignment** () and **Qt::Alignment** .
        """
        ...

    def font(self) -> QtGui.QFont:
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#font

        **QFont QTableWidgetItem::font() const**

        Returns the font used to render the item's text.

        **See also** **setFont** ().
        """
        ...

    def whatsThis(self) -> str:
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#whatsThis

        **QString QTableWidgetItem::whatsThis() const**

        Returns the item's "What's This?" help.

        **See also** **setWhatsThis** ().
        """
        ...

    def toolTip(self) -> str:
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#toolTip

        **QString QTableWidgetItem::toolTip() const**

        Returns the item's tooltip.

        **See also** **setToolTip** ().
        """
        ...

    def statusTip(self) -> str:
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#statusTip

        **QString QTableWidgetItem::statusTip() const**

        Returns the item's status tip.

        **See also** **setStatusTip** ().
        """
        ...

    def icon(self) -> QtGui.QIcon:
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#icon

        **QIcon QTableWidgetItem::icon() const**

        Returns the item's icon.

        **See also** **setIcon** () and **iconSize** .
        """
        ...

    def text(self) -> str:
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#text

        **QString QTableWidgetItem::text() const**

        Returns the item's text.

        **See also** **setText** ().
        """
        ...

    def flags(self) -> QtCore.Qt.ItemFlag:
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#flags

        **Qt::ItemFlags QTableWidgetItem::flags() const**

        Returns the flags used to describe the item. These determine whether the
        item can be checked, edited, and selected.

        **See also** **setFlags** ().
        """
        ...

    def tableWidget(self) -> "QTableWidget":
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#tableWidget

        **QTableWidget *QTableWidgetItem::tableWidget() const**

        Returns the table widget that contains the item.
        """
        ...

    def clone(self) -> "QTableWidgetItem":
        """
        https://doc.qt.io/qt-6/qtablewidgetitem.html#clone

        **[virtual] QTableWidgetItem *QTableWidgetItem::clone() const**

        Creates a copy of the item.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QShortcut(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qshortcut.html

    **Detailed Description**

    The QShortcut class provides a way of connecting keyboard shortcuts to Qt's
    **signals and slots**  mechanism, so that objects can be informed when a
    shortcut is executed. The shortcut can be set up to contain all the key
    presses necessary to describe a keyboard shortcut, including the states of
    modifier keys such as **Shift** , **Ctrl** , and **Alt**.

    In widget applications, certain widgets can use '&' in front of a character.
    This will automatically create a mnemonic (a shortcut) for that character,
    e.g. "E&xit" will create the shortcut **Alt+X** (use '&&' to display an
    actual ampersand). The widget might consume and perform an action on a given
    shortcut. On X11 the ampersand will not be shown and the character will be
    underlined. On Windows, shortcuts are normally not displayed until the user
    presses the **Alt** key, but this is a setting the user can change. On Mac,
    shortcuts are disabled by default. Call **qt_set_sequence_auto_mnemonic** ()
    to enable them. However, because mnemonic shortcuts do not fit in with
    Aqua's guidelines, Qt will not show the shortcut character underlined.

    For applications that use menus, it may be more convenient to use the
    convenience functions provided in the **QMenu**  class to assign keyboard
    shortcuts to menu items as they are created. Alternatively, shortcuts may be
    associated with other types of actions in the **QAction**  class.

    The simplest way to create a shortcut for a particular widget is to
    construct the shortcut with a key sequence. For example:

    shortcut = new **QShortcut** (**QKeySequence** (tr("Ctrl+O", "File|Open")),
    parent);

    When the user types the **key sequence**  for a given shortcut, the
    shortcut's **activated** () signal is emitted. (In the case of ambiguity,
    the **activatedAmbiguously** () signal is emitted.) A shortcut is "listened
    for" by Qt's event loop when the shortcut's parent widget is receiving
    events.

    A shortcut's key sequence can be set with **setKey** () and retrieved with
    **key** (). A shortcut can be enabled or disabled with **setEnabled** (),
    and can have "What's This?" help text set with **setWhatsThis** ().

    **See also** **QShortcutEvent** , **QKeySequence** , and **QAction** .
    """

    @typing.overload
    def __init__(
        self,
        key: QKeySequence.StandardKey,
        parent: QtCore.QObject,
        member: PYQT_SLOT = ...,
        ambiguousMember: PYQT_SLOT = ...,
        context: QtCore.Qt.ShortcutContext = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qshortcut.html#QShortcut

        **QShortcut::QShortcut(QObject * parent )**

        Constructs a QShortcut object for the **parent** , which should be a
        **QWindow**  or a **QWidget** .

        Since no shortcut key sequence is specified, the shortcut will not emit
        any signals.

        **See also** **setKey** ().
        """
        ...

    @typing.overload
    def __init__(
        self,
        key: typing.Union[QKeySequence, QKeySequence.StandardKey, str, int],
        parent: QtCore.QObject,
        member: PYQT_SLOT = ...,
        ambiguousMember: PYQT_SLOT = ...,
        context: QtCore.Qt.ShortcutContext = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qshortcut.html#QShortcut-1

        **QShortcut::QShortcut(const QKeySequence & key , QObject * parent ,
        const char * member = nullptr, const char * ambiguousMember = nullptr,
        Qt::ShortcutContext context = Qt::WindowShortcut)**

        Constructs a QShortcut object for the **parent** , which should be a
        **QWindow**  or a **QWidget** .

        The shortcut operates on its parent, listening for **QShortcutEvent** s
        that match the **key** sequence. Depending on the ambiguity of the
        event, the shortcut will call the **member** function, or the
        **ambiguousMember** function, if the key press was in the shortcut's
        **context**.
        """
        ...

    @typing.overload
    def __init__(self, parent: QtCore.QObject) -> None:
        """
        https://doc.qt.io/qt-6/qshortcut.html#QShortcut-2

        **[since 6.0] QShortcut::QShortcut(QKeySequence::StandardKey standardKey
        , QObject * parent , const char * member = nullptr, const char *
        ambiguousMember = nullptr, Qt::ShortcutContext context =
        Qt::WindowShortcut)**

        Constructs a QShortcut object for the **parent** , which should be a
        **QWindow**  or a **QWidget** .

        The shortcut operates on its parent, listening for **QShortcutEvent** s
        that match the **standardKey**. Depending on the ambiguity of the event,
        the shortcut will call the **member** function, or the
        **ambiguousMember** function, if the key press was in the shortcut's
        **context**.

        This function was introduced in Qt 6.0.
        """
        ...

    def event(self, e: QtCore.QEvent) -> bool:
        ...

    def keys(self) -> typing.List[QKeySequence]:
        """
        https://doc.qt.io/qt-6/qshortcut.html#keys

        **[since 6.0] QList<QKeySequence> QShortcut::keys() const**

        Returns the list of key sequences which trigger this shortcut.

        This function was introduced in Qt 6.0.

        **See also** **key**  and **setKeys** ().
        """
        ...

    @typing.overload
    def setKeys(
        self,
        keys: typing.Iterable[
            typing.Union[QKeySequence, QKeySequence.StandardKey, str, int]
        ],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qshortcut.html#setKeys

        **[since 6.0] void QShortcut::setKeys(QKeySequence::StandardKey key )**

        Sets the triggers to those matching the standard key **key**.

        This function was introduced in Qt 6.0.

        **See also** **key**  and **keys** ().
        """
        ...

    @typing.overload
    def setKeys(self, key: QKeySequence.StandardKey) -> None:
        """
        https://doc.qt.io/qt-6/qshortcut.html#setKeys-1

        **[since 6.0] void QShortcut::setKeys(const QList<QKeySequence> & keys
        )**

        Sets **keys** as the list of key sequences that trigger the shortcut.

        This function was introduced in Qt 6.0.

        **See also** **key**  and **keys** ().
        """
        ...

    def autoRepeat(self) -> bool:
        """
        https://doc.qt.io/qt-6/qshortcut.html#autoRepeat-prop

        **autoRepeat : bool**

        This property holds whether the shortcut can auto repeat

        If true, the shortcut will auto repeat when the keyboard shortcut
        combination is held down, provided that keyboard auto repeat is enabled
        on the system. The default value is true.

        **Access functions:**

        bool **autoRepeat** () const
        void **setAutoRepeat** (bool **on** )
        """
        ...

    def setAutoRepeat(self, on: bool) -> None:
        """
        https://doc.qt.io/qt-6/qshortcut.html#autoRepeat-prop

        **autoRepeat : bool**

        This property holds whether the shortcut can auto repeat

        If true, the shortcut will auto repeat when the keyboard shortcut
        combination is held down, provided that keyboard auto repeat is enabled
        on the system. The default value is true.

        **Access functions:**

        bool **autoRepeat** () const
        void **setAutoRepeat** (bool **on** )
        """
        ...

    def whatsThis(self) -> str:
        """
        https://doc.qt.io/qt-6/qshortcut.html#whatsThis

        **QString QShortcut::whatsThis() const**

        Returns the shortcut's "What's This?" help text.

        **See also** **setWhatsThis** ().
        """
        ...

    def setWhatsThis(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qshortcut.html#setWhatsThis

        **void QShortcut::setWhatsThis(const QString & text )**

        Sets the shortcut's "What's This?" help **text**.

        The text will be shown when a widget application is in "What's This?"
        mode and the user types the shortcut **key** () sequence.

        To set "What's This?" help on a menu item (with or without a shortcut
        key), set the help on the item's action.

        By default, the help text is an empty string.

        This function has no effect in applications that don't use widgets.

        **See also** **whatsThis** (), **QWhatsThis::inWhatsThisMode** (), and
        **QAction::setWhatsThis** ().
        """
        ...

    def context(self) -> QtCore.Qt.ShortcutContext:
        """
        https://doc.qt.io/qt-6/qshortcut.html#context-prop

        **context : Qt::ShortcutContext**

        This property holds the context in which the shortcut is valid

        A shortcut's context decides in which circumstances a shortcut is
        allowed to be triggered. The normal context is **Qt::WindowShortcut** ,
        which allows the shortcut to trigger if the parent (the widget
        containing the shortcut) is a subwidget of the active top-level window.

        By default, this property is set to **Qt::WindowShortcut** .

        **Access functions:**

        Qt::ShortcutContext **context** () const
        void **setContext**
        (Qt::ShortcutContext **context** )
        """
        ...

    def setContext(self, context: QtCore.Qt.ShortcutContext) -> None:
        """
        https://doc.qt.io/qt-6/qshortcut.html#context-prop

        **context : Qt::ShortcutContext**

        This property holds the context in which the shortcut is valid

        A shortcut's context decides in which circumstances a shortcut is
        allowed to be triggered. The normal context is **Qt::WindowShortcut** ,
        which allows the shortcut to trigger if the parent (the widget
        containing the shortcut) is a subwidget of the active top-level window.

        By default, this property is set to **Qt::WindowShortcut** .

        **Access functions:**

        Qt::ShortcutContext **context** () const
        void **setContext**
        (Qt::ShortcutContext **context** )
        """
        ...

    def isEnabled(self) -> bool:
        ...

    def setEnabled(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qshortcut.html#enabled-prop

        **enabled : bool**

        This property holds whether the shortcut is enabled

        An enabled shortcut emits the **activated** () or
        **activatedAmbiguously** () signal when a **QShortcutEvent**  occurs
        that matches the shortcut's **key** () sequence.

        If the application is in `WhatsThis` mode the shortcut will not emit the
        signals, but will show the "What's This?" text instead.

        By default, this property is `true`.

        **Access functions:**

        bool **isEnabled** () const
        void **setEnabled** (bool **enable** )

        **See also** **whatsThis** .
        """
        ...

    def key(self) -> QKeySequence:
        """
        https://doc.qt.io/qt-6/qshortcut.html#key-prop

        **key : QKeySequence**

        This property holds the shortcut's primary key sequence

        This is a key sequence with an optional combination of Shift, Ctrl, and
        Alt. The key sequence may be supplied in a number of ways:

        setKey(0);                  // no signal emitted
        setKey(**QKeySequence** ());     // no signal emitted
            setKey(0x3b1);
        // Greek letter alpha
            setKey(Qt::Key_D);              // 'd', e.g.
        to delete
            setKey('q');                // 'q', e.g. to quit
        setKey(Qt::CTRL | Qt::Key_P);       // Ctrl+P, e.g. to print document
        setKey("Ctrl+P");           // Ctrl+P, e.g. to print document

        By default, this property contains an empty key sequence.

        **Access functions:**

        QKeySequence **key** () const
        void **setKey** (const QKeySequence &
        **key** )

        **Member Function Documentation**
        """
        ...

    def setKey(
        self, key: typing.Union[QKeySequence, QKeySequence.StandardKey, str, int]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qshortcut.html#key-prop

        **key : QKeySequence**

        This property holds the shortcut's primary key sequence

        This is a key sequence with an optional combination of Shift, Ctrl, and
        Alt. The key sequence may be supplied in a number of ways:

        setKey(0);                  // no signal emitted
        setKey(**QKeySequence** ());     // no signal emitted
            setKey(0x3b1);
        // Greek letter alpha
            setKey(Qt::Key_D);              // 'd', e.g.
        to delete
            setKey('q');                // 'q', e.g. to quit
        setKey(Qt::CTRL | Qt::Key_P);       // Ctrl+P, e.g. to print document
        setKey("Ctrl+P");           // Ctrl+P, e.g. to print document

        By default, this property contains an empty key sequence.

        **Access functions:**

        QKeySequence **key** () const
        void **setKey** (const QKeySequence &
        **key** )

        **Member Function Documentation**
        """
        ...

    @property
    def activated(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qshortcut.html#activated

        **[signal] void QShortcut::activated()**

        This signal is emitted when the user types the shortcut's key sequence.

        **See also** **activatedAmbiguously** ().
        """
        ...

    @property
    def activatedAmbiguously(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qshortcut.html#activatedAmbiguously

        **[signal] void QShortcut::activatedAmbiguously()**

        When a key sequence is being typed at the keyboard, it is said to be
        ambiguous as long as it matches the start of more than one shortcut.

        When a shortcut's key sequence is completed, activatedAmbiguously() is
        emitted if the key sequence is still ambiguous (i.e., it is the start of
        one or more other shortcuts). The **activated** () signal is not emitted
        in this case.

        **See also** **activated** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QDBusUnixFileDescriptor(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qdbusunixfiledescriptor.html

    **Detailed Description**

    The QDBusUnixFileDescriptor class is used to hold one Unix file descriptor
    for use with the Qt D-Bus module. This allows applications to send and
    receive Unix file descriptors over the D-Bus connection, mapping
    automatically to the D-Bus type 'h'.

    Objects of type QDBusUnixFileDescriptors can be used also as parameters in
    signals and slots that get exported to D-Bus by registering with
    **QDBusConnection::registerObject** .

    QDBusUnixFileDescriptor does not take ownership of the file descriptor.
    Instead, it will use the Unix system call `dup(2)` to make a copy of the
    file descriptor. This file descriptor belongs to the QDBusUnixFileDescriptor
    object and should not be stored or closed by the user. Instead, you should
    make your own copy if you need that.

    **Availability**

    Unix file descriptor passing is not available in all D-Bus connections. This
    feature is present with D-Bus library and bus daemon version 1.4 and upwards
    on Unix systems. Qt D-Bus automatically enables the feature if such a
    version was found at compile-time and run-time.

    To verify that your connection does support passing file descriptors, check
    if the **QDBusConnection::UnixFileDescriptorPassing**  capability is set
    with **QDBusConnection::connectionCapabilities** (). If the flag is not
    active, then you will not be able to make calls to methods that have
    QDBusUnixFileDescriptor as arguments or even embed such a type in a variant.
    You will also not receive calls containing that type.

    Note also that remote applications may not have support for Unix file
    descriptor passing. If you make a D-Bus to a remote application that cannot
    receive such a type, you will receive an error reply. If you try to send a
    signal containing a D-Bus file descriptor or return one from a method call,
    the message will be silently dropped.

    Even if the feature is not available, QDBusUnixFileDescriptor will continue
    to operate, so code need not have compile-time checks for the availability
    of this feature.

    On non-Unix systems, QDBusUnixFileDescriptor will always report an invalid
    state and **QDBusUnixFileDescriptor::isSupported** () will return false.

    **See also** **QDBusConnection::ConnectionCapabilities**  and
    **QDBusConnection::connectionCapabilities** ().
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qdbusunixfiledescriptor.html#QDBusUnixFileDescrip
        tor

        **QDBusUnixFileDescriptor::QDBusUnixFileDescriptor()**

        Constructs a QDBusUnixFileDescriptor without a wrapped file descriptor.
        This is equivalent to constructing the object with an invalid file
        descriptor (like -1).

        **See also** **fileDescriptor** () and **isValid** ().
        """
        ...

    @typing.overload
    def __init__(self, fileDescriptor: int) -> None:
        """
        https://doc.qt.io/qt-6/qdbusunixfiledescriptor.html#QDBusUnixFileDescrip
        tor-1

        **QDBusUnixFileDescriptor::QDBusUnixFileDescriptor(int fileDescriptor
        )**

        Constructs a QDBusUnixFileDescriptor object by copying the
        **fileDescriptor** parameter. The original file descriptor is not
        touched and must be closed by the user.

        Note that the value returned by **fileDescriptor** () will be different
        from the **fileDescriptor** parameter passed.

        If the **fileDescriptor** parameter is not valid, **isValid** () will
        return false and **fileDescriptor** () will return -1.

        **See also** **setFileDescriptor** () and **fileDescriptor** ().
        """
        ...

    @typing.overload
    def __init__(self, other: "QDBusUnixFileDescriptor") -> None:
        """
        https://doc.qt.io/qt-6/qdbusunixfiledescriptor.html#QDBusUnixFileDescrip
        tor-2

        **QDBusUnixFileDescriptor::QDBusUnixFileDescriptor(const
        QDBusUnixFileDescriptor & other )**

        Constructs a QDBusUnixFileDescriptor object by copying **other**.
        """
        ...

    def swap(self, other: "QDBusUnixFileDescriptor") -> None:
        """
        https://doc.qt.io/qt-6/qdbusunixfiledescriptor.html#swap

        **[since 5.0] void QDBusUnixFileDescriptor::swap(QDBusUnixFileDescriptor
        & other )**

        Swaps this file descriptor instance with **other**. This function is
        very fast and never fails.

        This function was introduced in Qt 5.0.
        """
        ...

    @staticmethod
    def isSupported() -> bool:
        """
        https://doc.qt.io/qt-6/qdbusunixfiledescriptor.html#isSupported

        **[static] bool QDBusUnixFileDescriptor::isSupported()**

        Returns `true` if Unix file descriptors are supported on this platform.
        In other words, this function returns `true` if this is a Unix platform.

        Note that **QDBusUnixFileDescriptor**  continues to operate even if this
        function returns `false`. The only difference is that the
        **QDBusUnixFileDescriptor**  objects will always be in the **isValid**
        () == false state and **fileDescriptor** () will always return -1. The
        class will not consume any operating system resources.
        """
        ...

    def setFileDescriptor(self, fileDescriptor: int) -> None:
        """
        https://doc.qt.io/qt-6/qdbusunixfiledescriptor.html#setFileDescriptor

        **void QDBusUnixFileDescriptor::setFileDescriptor(int fileDescriptor )**

        Sets the file descriptor that this **QDBusUnixFileDescriptor**  object
        holds to a copy of **fileDescriptor**. The original file descriptor is
        not touched and must be closed by the user.

        Note that the value returned by **fileDescriptor** () will be different
        from the **fileDescriptor** parameter passed.

        If the **fileDescriptor** parameter is not valid, **isValid** () will
        return false and **fileDescriptor** () will return -1.

        **See also** **isValid** () and **fileDescriptor** ().
        """
        ...

    def fileDescriptor(self) -> int:
        """
        https://doc.qt.io/qt-6/qdbusunixfiledescriptor.html#fileDescriptor

        **int QDBusUnixFileDescriptor::fileDescriptor() const**

        Returns the Unix file descriptor contained by this
        **QDBusUnixFileDescriptor**  object. An invalid file descriptor is
        represented by the value -1.

        Note that the file descriptor returned by this function is owned by the
        **QDBusUnixFileDescriptor**  object and must not be stored past the
        lifetime of this object. It is ok to use it while this object is valid,
        but if one wants to store it for longer use, the file descriptor should
        be cloned using the Unix `dup(2)`, `dup2(2)` or `dup3(2)` functions.

        **See also** **setFileDescriptor** () and **isValid** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdbusunixfiledescriptor.html#isValid

        **bool QDBusUnixFileDescriptor::isValid() const**

        Returns `true` if this Unix file descriptor is valid. A valid Unix file
        descriptor is not -1.

        **See also** **fileDescriptor** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore


class QHelpSearchResult(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qhelpsearchresult.html

    **Detailed Description**

    The QHelpSearchResult object is a data object that describes a single search
    result. The vector of search result objects is returned by
    **QHelpSearchEngine::searchResults** (). The description of the search
    result contains the document title and URL that the search input matched. It
    also contains the snippet from the document content containing the best
    match of the search input.

    **See also** **QHelpSearchEngine** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qhelpsearchresult.html#QHelpSearchResult

        **QHelpSearchResult::QHelpSearchResult()**

        Constructs a new empty QHelpSearchResult.
        """
        ...

    @typing.overload
    def __init__(self, other: "QHelpSearchResult") -> None:
        """
        https://doc.qt.io/qt-6/qhelpsearchresult.html#QHelpSearchResult-1

        **QHelpSearchResult::QHelpSearchResult(const QHelpSearchResult & other
        )**

        Constructs a copy of **other**.
        """
        ...

    @typing.overload
    def __init__(self, url: QtCore.QUrl, title: str, snippet: str) -> None:
        """
        https://doc.qt.io/qt-6/qhelpsearchresult.html#QHelpSearchResult-2

        **QHelpSearchResult::QHelpSearchResult(const QUrl & url , const QString
        & title , const QString & snippet )**

        Constructs the search result containing **url** , **title** and
        **snippet** as the description of the result.
        """
        ...

    def snippet(self) -> str:
        """
        https://doc.qt.io/qt-6/qhelpsearchresult.html#snippet

        **QString QHelpSearchResult::snippet() const**

        Returns the document snippet containing the search phrase of the search
        result.
        """
        ...

    def url(self) -> QtCore.QUrl:
        """
        https://doc.qt.io/qt-6/qhelpsearchresult.html#url

        **QUrl QHelpSearchResult::url() const**

        Returns the document URL of the search result.
        """
        ...

    def title(self) -> str:
        """
        https://doc.qt.io/qt-6/qhelpsearchresult.html#title

        **QString QHelpSearchResult::title() const**

        Returns the document title of the search result.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtBluetooth import *
import enum


class QLowEnergyController(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qlowenergycontroller.html

    **Detailed Description**

    QLowEnergyController acts as the entry point for Bluetooth Low Energy
    development.

    Bluetooth Low Energy defines two types of devices; the peripheral and the
    central. Each role performs a different task. The peripheral device provides
    data which is utilized by central devices. An example might be a humidity
    sensor which measures the moisture in a winter garden. A device such as a
    mobile phone might read the sensor's value and display it to the user in the
    greater context of all sensors in the same environment. In this case the
    sensor is the peripheral device and the mobile phone acts as the central
    device.

    A controller in the central role is created via the **createCentral** ()
    factory method. Such an object essentially acts as a placeholder towards a
    remote Low Energy peripheral device, enabling features such as service
    discovery and state tracking.

    After having created a controller object in the central role, the first step
    is to establish a connection via **connectToDevice** (). Once the connection
    has been established, the controller's **state** () changes to
    **QLowEnergyController::ConnectedState**  and the **connected** () signal is
    emitted. It is important to mention that some platforms such as a BlueZ
    based Linux cannot maintain two connected instances of
    **QLowEnergyController**  to the same remote device. In such cases the
    second call to **connectToDevice** () may fail. This limitation may
    disappear at some stage in the future. The **disconnectFromDevice** ()
    function is used to break the existing connection.

    The second step after establishing the connection is to discover the
    services offered by the remote peripheral device. This process is started
    via **discoverServices** () and has finished once the **discoveryFinished**
    () signal has been emitted. The discovered services can be enumerated via
    **services** ().

    The last step is to create service objects. The **createServiceObject** ()
    function acts as factory for each service object and expects the service
    UUID as parameter. The calling context should take ownership of the returned
    **QLowEnergyService**  instance.

    Any **QLowEnergyService** , **QLowEnergyCharacteristic**  or
    **QLowEnergyDescriptor**  instance which is later created from this
    controller's connection becomes invalid as soon as the controller
    disconnects from the remote Bluetooth Low Energy device.

    A controller in the peripheral role is created via the **createPeripheral**
    () factory method. Such an object acts as a peripheral device itself,
    enabling features such as advertising services and allowing clients to get
    notified about changes to characteristic values.

    After having created a controller object in the peripheral role, the first
    step is to populate the set of GATT services offered to client devices via
    calls to **addService** (). Afterwards, one would call **startAdvertising**
    () to let the device broadcast some data and, depending on the type of
    advertising being done, also listen for incoming connections from GATT
    clients.

    **See also** **QLowEnergyService** , **QLowEnergyCharacteristic** ,
    **QLowEnergyDescriptor** , **QLowEnergyAdvertisingParameters** , and
    **QLowEnergyAdvertisingData** .
    """

    class Role(enum.Enum):
        CentralRole: QLowEnergyController = ...
        PeripheralRole: QLowEnergyController = ...

    class RemoteAddressType(enum.Enum):
        PublicAddress: QLowEnergyController = ...
        RandomAddress: QLowEnergyController = ...

    class ControllerState(enum.Enum):
        UnconnectedState: QLowEnergyController = ...
        ConnectingState: QLowEnergyController = ...
        ConnectedState: QLowEnergyController = ...
        DiscoveringState: QLowEnergyController = ...
        DiscoveredState: QLowEnergyController = ...
        ClosingState: QLowEnergyController = ...
        AdvertisingState: QLowEnergyController = ...

    class Error(enum.Enum):
        NoError: QLowEnergyController = ...
        UnknownError: QLowEnergyController = ...
        UnknownRemoteDeviceError: QLowEnergyController = ...
        NetworkError: QLowEnergyController = ...
        InvalidBluetoothAdapterError: QLowEnergyController = ...
        ConnectionError: QLowEnergyController = ...
        AdvertisingError: QLowEnergyController = ...
        RemoteHostClosedError: QLowEnergyController = ...
        AuthorizationError: QLowEnergyController = ...

    def remoteDeviceUuid(self) -> QBluetoothUuid:
        """
        https://doc.qt.io/qt-6/qlowenergycontroller.html#remoteDeviceUuid

        **[since 5.8] QBluetoothUuid QLowEnergyController::remoteDeviceUuid()
        const**

        Returns the unique identifier of the remote Bluetooth Low Energy device.

        On macOS/iOS/tvOS CoreBluetooth does not expose/accept hardware
        addresses for LE devices; instead developers are supposed to use unique
        128-bit UUIDs, generated by CoreBluetooth. These UUIDS will stay
        constant for the same central <-> peripheral pair and we use them when
        connecting to a remote device. For a controller in the **CentralRole** ,
        this value will always be the one passed in when the controller object
        was created. For a controller in the **PeripheralRole** , this value is
        invalid.

        This function was introduced in Qt 5.8.
        """
        ...

    def role(self) -> "QLowEnergyController.Role":
        """
        https://doc.qt.io/qt-6/qlowenergycontroller.html#role

        **[since 5.7] QLowEnergyController::Role QLowEnergyController::role()
        const**

        Returns the role that this controller object is in.

        The role is determined when constructing a **QLowEnergyController**
        instance using **createCentral** () or **createPeripheral** ().

        This function was introduced in Qt 5.7.
        """
        ...

    def requestConnectionUpdate(
        self, parameters: QLowEnergyConnectionParameters
    ) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergycontroller.html#requestConnectionUpdate

        **[since 5.7] void QLowEnergyController::requestConnectionUpdate(const
        QLowEnergyConnectionParameters & parameters )**

        Requests the controller to update the connection according to
        **parameters**. If the request is successful, the **connectionUpdated**
        () signal will be emitted with the actual new parameters. See the
        **QLowEnergyConnectionParameters**  class for more information on
        connection parameters.

        Android only indirectly permits the adjustment of this parameter set.
        The connection parameters are separated into three categories (high, low
        & balanced priority). Each category implies a pre-configured set of
        values for **QLowEnergyConnectionParameters::minimumInterval** (),
        **QLowEnergyConnectionParameters::maximumInterval** () and
        **QLowEnergyConnectionParameters::latency** (). Although the connection
        request is an asynchronous operation, Android does not provide a
        callback stating the result of the request. This is an acknowledged
        Android bug. Due to this bug Android does not emit the
        **connectionUpdated** () signal.

        **Note:** Currently, this functionality is only implemented on Linux and
        Android.

        This function was introduced in Qt 5.7.

        **See also** **connectionUpdated** ().
        """
        ...

    def addService(
        self,
        service: "QLowEnergyServiceData",
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> "QLowEnergyService":
        """
        https://doc.qt.io/qt-6/qlowenergycontroller.html#addService

        **[since 5.7] QLowEnergyService *QLowEnergyController::addService(const
        QLowEnergyServiceData & service , QObject * parent = nullptr)**

        Constructs and returns a **QLowEnergyService**  object with **parent**
        from **service**. The controller must be in the **PeripheralRole**  and
        in the **UnconnectedState** . The **service** object must be valid.

        **Note:** Once the peripheral instance is disconnected from the remote
        central device or if **disconnectFromDevice** () is manually called,
        every service definition that was previously added via this function is
        removed from the peripheral. Therefore this function must be called
        again before re-advertising this peripheral controller instance. The
        described behavior is connection specific and therefore not dependent on
        whether **stopAdvertising** () was called.

        This function was introduced in Qt 5.7.

        **See also** **stopAdvertising** (), **disconnectFromDevice** (), and
        **QLowEnergyServiceData::addIncludedService** .
        """
        ...

    def stopAdvertising(self) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergycontroller.html#stopAdvertising

        **[since 5.7] void QLowEnergyController::stopAdvertising()**

        Stops advertising, if this object is currently in the advertising state.

        The controller has to be in the **PeripheralRole**  for this function to
        work. It does not invalidate services which have previously been added
        via **addService** ().

        This function was introduced in Qt 5.7.

        **See also** **startAdvertising** ().
        """
        ...

    def startAdvertising(
        self,
        parameters: QLowEnergyAdvertisingParameters,
        advertisingData: QLowEnergyAdvertisingData,
        scanResponseData: QLowEnergyAdvertisingData = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergycontroller.html#startAdvertising

        **[since 5.7] void QLowEnergyController::startAdvertising(const
        QLowEnergyAdvertisingParameters & parameters , const
        QLowEnergyAdvertisingData & advertisingData , const
        QLowEnergyAdvertisingData & scanResponseData =
        QLowEnergyAdvertisingData())**

        Starts advertising the data given in **advertisingData** and
        **scanResponseData** , using the parameters set in **parameters**. The
        controller has to be in the **PeripheralRole** . If **parameters**
        indicates that the advertisement should be connectable, then this
        function also starts listening for incoming client connections.

        Providing **scanResponseData** is not required, as it is not applicable
        for certain configurations of `parameters`. **advertisingData** and
        **scanResponseData** are limited to 31 byte user data. If, for example,
        several 128bit uuids are added to **advertisingData** , the advertised
        packets may not contain all uuids. The existing limit may have caused
        the truncation of uuids. In such cases **scanResponseData** may be used
        for additional information.

        If this object is currently not in the **UnconnectedState** , nothing
        happens.

        **Note:** Advertising will stop automatically once a client connects to
        the local device.

        This function was introduced in Qt 5.7.

        **See also** **stopAdvertising** ().
        """
        ...

    @typing.overload
    @staticmethod
    def createPeripheral(
        localDevice: QBluetoothAddress, parent: typing.Optional[QtCore.QObject] = ...
    ) -> "QLowEnergyController":
        """
        https://doc.qt.io/qt-6/qlowenergycontroller.html#createPeripheral

        **[static, since 6.2] QLowEnergyController
        *QLowEnergyController::createPeripheral(const QBluetoothAddress &
        localDevice , QObject * parent = nullptr)**

        Returns a new object of this class that is in the **PeripheralRole**
        and has the parent object **parent** and is using **localDevice**.
        Typically, the next steps are to add some services and finally call
        **startAdvertising** () on the returned object.

        The peripheral is created on **localDevice**. If **localDevice** is
        invalid, the local default device is automatically selected. If
        **localDevice** specifies a local device that is not a local Bluetooth
        adapter, **error** () is set to **InvalidBluetoothAdapterError** .

        Selecting **localDevice** is only supported on Linux. On other platform,
        the parameter is ignored.

        This function was introduced in Qt 6.2.

        **See also** **QLowEnergyController::PeripheralRole** .
        """
        ...

    @typing.overload
    @staticmethod
    def createPeripheral(
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> "QLowEnergyController":
        """
        https://doc.qt.io/qt-6/qlowenergycontroller.html#createPeripheral-1

        **[static, since 5.7] QLowEnergyController
        *QLowEnergyController::createPeripheral(QObject * parent = nullptr)**

        Returns a new object of this class that is in the **PeripheralRole**
        and has the parent object **parent**. Typically, the next steps are to
        add some services and finally call **startAdvertising** () on the
        returned object.

        The controller uses the local default Bluetooth adapter for the
        connection management.

        This function was introduced in Qt 5.7.

        **See also** **QLowEnergyController::PeripheralRole** .
        """
        ...

    @typing.overload
    @staticmethod
    def createCentral(
        remoteDevice: QBluetoothDeviceInfo,
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> "QLowEnergyController":
        """
        https://doc.qt.io/qt-6/qlowenergycontroller.html#createCentral

        **[static, since 5.7] QLowEnergyController
        *QLowEnergyController::createCentral(const QBluetoothDeviceInfo &
        remoteDevice , QObject * parent = nullptr)**

        Returns a new object of this class that is in the **CentralRole**  and
        has the parent object **parent**. The **remoteDevice** refers to the
        device that a connection will be established to later.

        The controller uses the local default Bluetooth adapter for the
        connection management.

        This function was introduced in Qt 5.7.

        **See also** **QLowEnergyController::CentralRole** .
        """
        ...

    @typing.overload
    @staticmethod
    def createCentral(
        remoteDevice: QBluetoothDeviceInfo,
        localDevice: QBluetoothAddress,
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> "QLowEnergyController":
        """
        https://doc.qt.io/qt-6/qlowenergycontroller.html#createCentral-1

        **[static, since 5.14] QLowEnergyController
        *QLowEnergyController::createCentral(const QBluetoothDeviceInfo &
        remoteDevice , const QBluetoothAddress & localDevice , QObject * parent
        = nullptr)**

        Returns a new instance of this class with **parent**.

        The **remoteDevice** must contain the address of the remote Bluetooth
        Low Energy device to which this object should attempt to connect later
        on.

        The connection is established via **localDevice**. If **localDevice** is
        invalid, the local default device is automatically selected. If
        **localDevice** specifies a local device that is not a local Bluetooth
        adapter, **error** () is set to **InvalidBluetoothAdapterError**  once
        **connectToDevice** () is called.

        Note that specifying the local device to be used for the connection is
        only possible when using BlueZ. All other platforms do not support this
        feature.

        This function was introduced in Qt 5.14.
        """
        ...

    def mtu(self) -> int:
        """
        https://doc.qt.io/qt-6/qlowenergycontroller.html#mtu

        **[since 6.2] int QLowEnergyController::mtu() const**

        Returns the MTU size.

        During connection setup, the ATT MTU size is negotiated. This method
        provides the result of this negotiation. It can be used to optimize
        packet sizes in some situations. The maximum amount of data which can be
        transferred in a single packet is **mtu-3** bytes. 3 bytes are required
        for the ATT protocol header.

        Before the connection setup and MTU negotiation, the default value of
        `23` will be returned.

        Not every platform exposes the MTU value. On those platforms (e.g.
        Linux) this function always returns `-1`.

        If the controller is in the **PeripheralRole** , there might be several
        central devices connected to it. In those cases this function returns
        the MTU of the last connection that was negotiated.

        This function was introduced in Qt 6.2.
        """
        ...

    def remoteName(self) -> str:
        """
        https://doc.qt.io/qt-6/qlowenergycontroller.html#remoteName

        **[since 5.5] QString QLowEnergyController::remoteName() const**

        Returns the name of the remote Bluetooth Low Energy device, if the
        controller is in the **CentralRole** . Otherwise the result is
        unspecified.

        This function was introduced in Qt 5.5.
        """
        ...

    def errorString(self) -> str:
        """
        https://doc.qt.io/qt-6/qlowenergycontroller.html#errorString

        **QString QLowEnergyController::errorString() const**

        Returns a textual representation of the last occurred error. The string
        is translated.
        """
        ...

    def error(self) -> "QLowEnergyController.Error":
        """
        https://doc.qt.io/qt-6/qlowenergycontroller.html#error

        **QLowEnergyController::Error QLowEnergyController::error() const**

        Returns the last occurred error or **NoError** .
        """
        ...

    def createServiceObject(
        self, service: QBluetoothUuid, parent: typing.Optional[QtCore.QObject] = ...
    ) -> "QLowEnergyService":
        """
        https://doc.qt.io/qt-6/qlowenergycontroller.html#createServiceObject

        **QLowEnergyService *QLowEnergyController::createServiceObject(const
        QBluetoothUuid & serviceUuid , QObject * parent = nullptr)**

        Creates an instance of the service represented by **serviceUuid**. The
        **serviceUuid** parameter must have been obtained via **services** ().

        The caller takes ownership of the returned pointer and may pass a
        **parent** parameter as default owner.

        This function returns a null pointer if no service with **serviceUuid**
        can be found on the remote device or the controller is disconnected.

        This function can return instances for secondary services too. The
        include relationships between services can be expressed via
        **QLowEnergyService::includedServices** ().

        If this function is called multiple times using the same service UUID,
        the returned **QLowEnergyService**  instances share their internal data.
        Therefore if one of the instances initiates the discovery of the service
        details, the other instances automatically transition into the discovery
        state too.

        **See also** **services** ().
        """
        ...

    def services(self) -> typing.List[QBluetoothUuid]:
        """
        https://doc.qt.io/qt-6/qlowenergycontroller.html#services

        **QList<QBluetoothUuid> QLowEnergyController::services() const**

        Returns the list of services offered by the remote device, if the
        controller is in the **CentralRole** . Otherwise, the result is
        unspecified.

        The list contains all primary and secondary services.

        **See also** **createServiceObject** ().
        """
        ...

    def discoverServices(self) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergycontroller.html#discoverServices

        **void QLowEnergyController::discoverServices()**

        Initiates the service discovery process.

        The discovery progress is indicated via the **serviceDiscovered** ()
        signal. The **discoveryFinished** () signal is emitted when the process
        has finished.

        If the controller instance is not connected or the controller has
        performed the service discovery already this function will do nothing.

        **Note:** Some platforms internally cache the service list of a device
        which was discovered in the past. This can be problematic if the remote
        device changed its list of services or their inclusion tree. If this
        behavior is a problem, the best workaround is to temporarily turn
        Bluetooth off. This causes a reset of the cache data. Currently Android
        exhibits such a cache behavior.
        """
        ...

    def disconnectFromDevice(self) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergycontroller.html#disconnectFromDevice

        **void QLowEnergyController::disconnectFromDevice()**

        Disconnects from the remote device.

        Any **QLowEnergyService** , **QLowEnergyCharacteristic**  or
        **QLowEnergyDescriptor**  instance that resulted from the current
        connection is automatically invalidated. Once any of those objects
        become invalid they remain invalid even if this controller object
        reconnects.

        This function does nothing if the controller is in the
        **UnconnectedState** .

        If the controller is in the peripheral role, it stops advertising and
        removes all services which have previously been added via **addService**
        (). To reuse the **QLowEnergyController**  instance the application must
        re-add services and restart the advertising mode by calling
        **startAdvertising** ().

        **See also** **connectToDevice** ().
        """
        ...

    def connectToDevice(self) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergycontroller.html#connectToDevice

        **void QLowEnergyController::connectToDevice()**

        Connects to the remote Bluetooth Low Energy device.

        This function does nothing if the controller's **state** () is not equal
        to **UnconnectedState** . The **connected** () signal is emitted once
        the connection is successfully established.

        On Linux/BlueZ systems, it is not possible to connect to the same remote
        device using two instances of this class. The second call to this
        function may fail with an error. This limitation may be removed in
        future releases.

        **See also** **disconnectFromDevice** ().
        """
        ...

    def setRemoteAddressType(
        self, type: "QLowEnergyController.RemoteAddressType"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergycontroller.html#setRemoteAddressType

        **void QLowEnergyController::setRemoteAddressType(QLowEnergyController::
        RemoteAddressType type )**

        Sets the remote address **type**. The type is required to connect to the
        remote Bluetooth Low Energy device.

        This attribute is only required to be set on Linux/BlueZ systems with
        older Linux kernels (v3.3 or lower), or if CAP_NET_ADMIN is not set for
        the executable. The default value of the attribute is **RandomAddress**
        .

        **Note:** All other platforms handle this flag transparently and
        therefore applications can ignore it entirely. On Linux, the address
        type flag is not directly exposed by BlueZ although some use cases do
        require this information. The only way to detect the flag is via the
        Linux kernel's Bluetooth Management API (kernel version 3.4+ required).
        This API requires CAP_NET_ADMIN capabilities though. If the local
        **QtBluetooth**  process has this capability set **QtBluetooth**  will
        use the API. This assumes that **QBluetoothDeviceDiscoveryAgent**  was
        used prior to calling **QLowEnergyController::connectToDevice** ().

        **See also** **remoteAddressType** ().
        """
        ...

    def remoteAddressType(self) -> "QLowEnergyController.RemoteAddressType":
        """
        https://doc.qt.io/qt-6/qlowenergycontroller.html#remoteAddressType

        **QLowEnergyController::RemoteAddressType
        QLowEnergyController::remoteAddressType() const**

        Returns the type of **remoteAddress** (). By default, this value is
        initialized to **PublicAddress** .

        **See also** **setRemoteAddressType** ().
        """
        ...

    def state(self) -> "QLowEnergyController.ControllerState":
        """
        https://doc.qt.io/qt-6/qlowenergycontroller.html#state

        **QLowEnergyController::ControllerState QLowEnergyController::state()
        const**

        Returns the current state of the controller.

        **See also** **stateChanged** ().
        """
        ...

    def remoteAddress(self) -> QBluetoothAddress:
        """
        https://doc.qt.io/qt-6/qlowenergycontroller.html#remoteAddress

        **QBluetoothAddress QLowEnergyController::remoteAddress() const**

        Returns the address of the remote Bluetooth Low Energy device.

        For a controller in the **CentralRole** , this value will always be the
        one passed in when the controller object was created. For a controller
        in the **PeripheralRole** , this value is one of the currently connected
        client device addresses. This address will be invalid if the controller
        is not currently in the **ConnectedState** .
        """
        ...

    def localAddress(self) -> QBluetoothAddress:
        """
        https://doc.qt.io/qt-6/qlowenergycontroller.html#localAddress

        **QBluetoothAddress QLowEnergyController::localAddress() const**

        Returns the address of the local Bluetooth adapter being used for the
        communication.

        If this class instance was requested to use the default adapter but
        there was no default adapter when creating this class instance, the
        returned **QBluetoothAddress**  will be null.

        **See also** **QBluetoothAddress::isNull** ().
        """
        ...

    @property
    def connected(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qlowenergycontroller.html#connected

        **[signal] void QLowEnergyController::connected()**

        This signal is emitted when the controller successfully connects to the
        remote Low Energy device (if the controller is in the **CentralRole** )
        or if a remote Low Energy device connected to the controller (if the
        controller is in the **PeripheralRole** ). On iOS, macOS, and Android
        this signal is not reliable if the controller is in the
        **PeripheralRole** . On iOS and macOS the controller only guesses that
        some central connected to our peripheral as soon as this central tries
        to write/read a characteristic/descriptor. On Android the controller
        monitors all connected GATT devices.
        """
        ...

    @property
    def connectionUpdated(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qlowenergycontroller.html#connectionUpdated

        **[signal, since 5.7] void QLowEnergyController::connectionUpdated(const
        QLowEnergyConnectionParameters & newParameters )**

        This signal is emitted when the connection parameters change. This can
        happen as a result of calling **requestConnectionUpdate** () or due to
        other reasons, for instance because the other side of the connection
        requested new parameters. The new values can be retrieved from
        **newParameters**.

        This function was introduced in Qt 5.7.

        **See also** **requestConnectionUpdate** ().
        """
        ...

    @property
    def disconnected(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qlowenergycontroller.html#disconnected

        **[signal] void QLowEnergyController::disconnected()**

        This signal is emitted when the controller disconnects from the remote
        Low Energy device or vice versa. On iOS and macOS this signal is
        unreliable if the controller is in the **PeripheralRole** . On Android
        the signal is emitted when the last connected device is disconnected.
        """
        ...

    @property
    def discoveryFinished(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qlowenergycontroller.html#discoveryFinished

        **[signal] void QLowEnergyController::discoveryFinished()**

        This signal is emitted when the running service discovery finishes. The
        signal is not emitted if the discovery process finishes with an error.

        This signal can only be emitted if the controller is in the
        **CentralRole** .

        **See also** **discoverServices** () and **error** ().
        """
        ...

    @property
    def errorOccurred(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qlowenergycontroller.html#errorOccurred

        **[signal, since 6.2] void
        QLowEnergyController::errorOccurred(QLowEnergyController::Error newError
        )**

        This signal is emitted when an error occurs. The **newError** parameter
        describes the error that occurred.

        This function was introduced in Qt 6.2.

        **See also** **error** () and **errorString** ().
        """
        ...

    @property
    def mtuChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qlowenergycontroller.html#mtuChanged

        **[signal] void QLowEnergyController::mtuChanged(int mtu )**

        This signal is emitted as a result of a successful MTU change. **mtu**
        represents the new value.

        **Note:** If the controller is in the **PeripheralRole** , the MTU value
        is negotiated for each client/central device individually. Therefore
        this signal can be emitted several times in a row for one or several
        devices.

        **See also** **mtu** ().
        """
        ...

    @property
    def serviceDiscovered(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qlowenergycontroller.html#serviceDiscovered

        **[signal] void QLowEnergyController::serviceDiscovered(const
        QBluetoothUuid & newService )**

        This signal is emitted each time a new service is discovered. The
        **newService** parameter contains the UUID of the found service.

        This signal can only be emitted if the controller is in the
        `CentralRole`.

        **See also** **discoverServices** () and **discoveryFinished** ().
        """
        ...

    @property
    def stateChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qlowenergycontroller.html#stateChanged

        **[signal] void
        QLowEnergyController::stateChanged(QLowEnergyController::ControllerState
        state )**

        This signal is emitted when the controller's state changes. The new
        **state** can also be retrieved via **state** ().

        **See also** **state** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QTabletEvent(QSinglePointEvent):
    """
    https://doc.qt.io/qt-6/qtabletevent.html

    **Detailed Description**

    **Tablet events** are generated from tablet peripherals such as Wacom
    tablets and various other brands, and electromagnetic stylus devices
    included with some types of tablet computers. (It is not the same as
    **QTouchEvent**  which a touchscreen generates, even when a passive stylus
    is used on a touchscreen.)

    Tablet events are similar to mouse events; for example, the **x** (), **y**
    (), **pos** (), **globalX** (), **globalY** (), and **globalPos** ()
    accessors provide the cursor position, and you can see which **buttons** ()
    are pressed (pressing the stylus tip against the tablet surface is
    equivalent to a left mouse button). But tablet events also pass through some
    extra information that the tablet device driver provides; for example, you
    might want to do subpixel rendering with higher resolution coordinates
    (**globalPosF** ()), adjust color brightness based on the **pressure** () of
    the tool against the tablet surface, use different brushes depending on the
    type of tool in use (**deviceType** ()), modulate the brush shape in some
    way according to the X-axis and Y-axis tilt of the tool with respect to the
    tablet surface (**xTilt** () and **yTilt** ()), and use a virtual eraser
    instead of a brush if the user switches to the other end of a double-ended
    stylus (**pointerType** ()).

    Every event contains an accept flag that indicates whether the receiver
    wants the event. You should call **QTabletEvent::accept** () if you handle
    the tablet event; otherwise it will be sent to the parent widget. The
    exception are TabletEnterProximity and TabletLeaveProximity events: these
    are only sent to **QApplication**  and do not check whether or not they are
    accepted.

    The **QWidget::setEnabled** () function can be used to enable or disable
    mouse, tablet and keyboard events for a widget.

    The event handler **QWidget::tabletEvent** () receives TabletPress,
    TabletRelease and TabletMove events. Qt will first send a tablet event, then
    if it is not accepted by any widget, it will send a mouse event. This allows
    users of applications that are not designed for tablets to use a tablet like
    a mouse. However high-resolution drawing applications should handle the
    tablet events, because they can occur at a higher frequency, which is a
    benefit for smooth and accurate drawing. If the tablet events are rejected,
    the synthetic mouse events may be compressed for efficiency.

    Note that pressing the stylus button while the stylus hovers over the tablet
    will generate a button press on some types of tablets, while on other types
    it will be necessary to press the stylus against the tablet surface in order
    to register the simultaneous stylus button press.

    **Notes for X11 Users**

    If the tablet is configured in xorg.conf to use the Wacom driver, there will
    be separate XInput "devices" for the stylus, eraser, and (optionally) cursor
    and touchpad. Qt recognizes these by their names. Otherwise, if the tablet
    is configured to use the evdev driver, there will be only one device and
    applications may not be able to distinguish the stylus from the eraser.

    **Notes for Windows Users**

    Tablet support currently requires the WACOM windows driver providing the DLL
    `wintab32.dll` to be installed. It is contained in older packages, for
    example `pentablet_5.3.5-3.exe`.
    """

    def __init__(
        self,
        t: QtCore.QEvent.Type,
        device: "QPointingDevice",
        pos: QtCore.QPointF,
        globalPos: QtCore.QPointF,
        pressure: float,
        xTilt: float,
        yTilt: float,
        tangentialPressure: float,
        rotation: float,
        z: float,
        keyState: QtCore.Qt.KeyboardModifier,
        button: QtCore.Qt.MouseButton,
        buttons: QtCore.Qt.MouseButton,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtabletevent.html#QTabletEvent-2

        **QTabletEvent::QTabletEvent(QEvent::Type type , const QPointingDevice *
        dev , const QPointF & pos , const QPointF & globalPos , qreal pressure ,
        float xTilt , float yTilt , float tangentialPressure , qreal rotation ,
        float z , Qt::KeyboardModifiers keyState , Qt::MouseButton button ,
        Qt::MouseButtons buttons )**

        Construct a tablet event of the given **type**.

        The **pos** parameter indicates where the event occurred in the widget;
        **globalPos** is the corresponding position in absolute coordinates.

        **pressure** gives the pressure exerted on the device **dev**.

        **xTilt** and **yTilt** give the device's degree of tilt from the x and
        y axes respectively.

        **keyState** specifies which keyboard modifiers are pressed (e.g.,
        **Ctrl** ).

        The **z** parameter gives the Z coordinate of the device on the tablet;
        this is usually given by a wheel on a 4D mouse. If the device does not
        support a Z-axis (i.e. **QPointingDevice::capabilities** () does not
        include `ZPosition`), pass `0` here.

        The **tangentialPressure** parameter gives the tangential pressure
        thumbwheel value from an airbrush. If the device does not support
        tangential pressure (i.e. **QPointingDevice::capabilities** () does not
        include `TangentialPressure`), pass `0` here.

        **rotation** gives the device's rotation in degrees. 4D mice, the Wacom
        Art Pen, and the Apple Pencil support rotation. If the device does not
        support rotation (i.e. **QPointingDevice::capabilities** () does not
        include `Rotation`), pass `0` here.

        The **button** that caused the event is given as a value from the
        **Qt::MouseButton**  enum. If the event **type** is not **TabletPress**
        or **TabletRelease** , the appropriate button for this event is
        **Qt::NoButton** .

        **buttons** is the state of all buttons at the time of the event.

        **See also** **pos** (), **globalPos** (), **device** (), **pressure**
        (), **xTilt** (), **yTilt** (), **uniqueId** (), **rotation** (),
        **tangentialPressure** (), and **z** ().
        """
        ...

    def clone(self) -> "QTabletEvent":
        ...

    def yTilt(self) -> float:
        """
        https://doc.qt.io/qt-6/qtabletevent.html#yTilt

        **qreal QTabletEvent::yTilt() const**

        Returns the angle between the device (a pen, for example) and the
        perpendicular in the direction of the y axis. Positive values are
        towards the bottom of the tablet. The angle is within the range -60 to
        +60 degrees.

        **Note:** The value is stored as a single-precision float.

        **See also** **xTilt** ().
        """
        ...

    def xTilt(self) -> float:
        """
        https://doc.qt.io/qt-6/qtabletevent.html#xTilt

        **qreal QTabletEvent::xTilt() const**

        Returns the angle between the device (a pen, for example) and the
        perpendicular in the direction of the x axis. Positive values are
        towards the tablet's physical right. The angle is in the range -60 to
        +60 degrees.

        ![](images/qtabletevent-tilt.png)

        **Note:** The value is stored as a single-precision float.

        **See also** **yTilt** ().
        """
        ...

    def tangentialPressure(self) -> float:
        """
        https://doc.qt.io/qt-6/qtabletevent.html#tangentialPressure

        **qreal QTabletEvent::tangentialPressure() const**

        Returns the tangential pressure for the device. This is typically given
        by a finger wheel on an airbrush tool. The range is from -1.0 to 1.0.
        0.0 indicates a neutral position. Current airbrushes can only move in
        the positive direction from the neutrual position. If the device does
        not support tangential pressure, this value is always 0.0.

        **Note:** The value is stored as a single-precision float.

        **See also** **pressure** ().
        """
        ...

    def z(self) -> float:
        """
        https://doc.qt.io/qt-6/qtabletevent.html#z

        **qreal QTabletEvent::z() const**

        Returns the z position of the device. Typically this is represented by a
        wheel on a 4D Mouse. If the device does not support a Z-axis, this value
        is always zero. This is **not** the same as pressure.

        **Note:** The value is stored as a single-precision float.

        **See also** **pressure** ().
        """
        ...

    def rotation(self) -> float:
        """
        https://doc.qt.io/qt-6/qtabletevent.html#rotation

        **qreal QTabletEvent::rotation() const**

        Returns the rotation of the current tool in degrees, where zero means
        the tip of the stylus is pointing towards the top of the tablet, a
        positive value means it's turned to the right, and a negative value
        means it's turned to the left. This can be given by a 4D Mouse or a
        rotation-capable stylus (such as the Wacom Art Pen or the Apple Pencil).
        If the device does not support rotation, this value is always 0.0.
        """
        ...

    def pressure(self) -> float:
        """
        https://doc.qt.io/qt-6/qtabletevent.html#pressure

        **qreal QTabletEvent::pressure() const**

        Returns the pressure for the device. 0.0 indicates that the stylus is
        not on the tablet, 1.0 indicates the maximum amount of pressure for the
        stylus.

        **See also** **tangentialPressure** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtSql import *
import enum


class QSqlError(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qsqlerror.html

    **Detailed Description**

    A QSqlError object can provide database-specific error data, including the
    **driverText** () and **databaseText** () messages (or both concatenated
    together as **text** ()), and the **nativeErrorCode** () and **type** ().

    **See also** **QSqlDatabase::lastError** () and **QSqlQuery::lastError** ().
    """

    class ErrorType(enum.Enum):
        NoError: QSqlError = ...
        ConnectionError: QSqlError = ...
        StatementError: QSqlError = ...
        TransactionError: QSqlError = ...
        UnknownError: QSqlError = ...

    @typing.overload
    def __init__(
        self,
        driverText: str = ...,
        databaseText: str = ...,
        type: "QSqlError.ErrorType" = ...,
        errorCode: str = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsqlerror.html#QSqlError

        **QSqlError::QSqlError(const QString & driverText = QString(), const
        QString & databaseText = QString(), QSqlError::ErrorType type = NoError,
        const QString & code = QString())**

        Constructs an error containing the driver error text **driverText** ,
        the database-specific error text **databaseText** , the type **type**
        and the error code **code**.

        **Note:** DB2: It is possible for DB2 to report more than one error
        code. When this happens, `;` is used as separator between the error
        codes.
        """
        ...

    @typing.overload
    def __init__(self, other: "QSqlError") -> None:
        """
        https://doc.qt.io/qt-6/qsqlerror.html#QSqlError-1

        **QSqlError::QSqlError(const QSqlError & other )**

        Creates a copy of **other**.
        """
        ...

    def swap(self, other: "QSqlError") -> None:
        """
        https://doc.qt.io/qt-6/qsqlerror.html#swap

        **[since 5.10] void QSqlError::swap(QSqlError & other )**

        Swaps error **other** with this error. This operation is very fast and
        never fails.

        This function was introduced in Qt 5.10.
        """
        ...

    def nativeErrorCode(self) -> str:
        """
        https://doc.qt.io/qt-6/qsqlerror.html#nativeErrorCode

        **QString QSqlError::nativeErrorCode() const**

        Returns the database-specific error code, or an empty string if it
        cannot be determined.
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlerror.html#isValid

        **bool QSqlError::isValid() const**

        Returns `true` if an error is set, otherwise false.

        Example:

        **QSqlQueryModel**  model;
            model.setQuery("select * from myTable");
        if (model.lastError().isValid())
                **qDebug** () <<
        model.lastError();

        **See also** **type** ().
        """
        ...

    def text(self) -> str:
        """
        https://doc.qt.io/qt-6/qsqlerror.html#text

        **QString QSqlError::text() const**

        This is a convenience function that returns **databaseText** () and
        **driverText** () concatenated into a single string.

        **See also** **driverText** () and **databaseText** ().
        """
        ...

    def type(self) -> "QSqlError.ErrorType":
        """
        https://doc.qt.io/qt-6/qsqlerror.html#type

        **QSqlError::ErrorType QSqlError::type() const**

        Returns the error type, or -1 if the type cannot be determined.
        """
        ...

    def databaseText(self) -> str:
        """
        https://doc.qt.io/qt-6/qsqlerror.html#databaseText

        **QString QSqlError::databaseText() const**

        Returns the text of the error as reported by the database. This may
        contain database-specific descriptions; it may be empty.

        **See also** **driverText** () and **text** ().
        """
        ...

    def driverText(self) -> str:
        """
        https://doc.qt.io/qt-6/qsqlerror.html#driverText

        **QString QSqlError::driverText() const**

        Returns the text of the error as reported by the driver. This may
        contain database-specific descriptions. It may also be empty.

        **See also** **databaseText** () and **text** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import PyQt6.sip
from PyQt6.QtMultimedia import *
import enum


class QAudio(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qaudio.html

    **Detailed Description**
    """

    class VolumeScale(enum.Enum):
        LinearVolumeScale: QAudio = ...
        CubicVolumeScale: QAudio = ...
        LogarithmicVolumeScale: QAudio = ...
        DecibelVolumeScale: QAudio = ...

    class State(enum.Enum):
        ActiveState: QAudio = ...
        SuspendedState: QAudio = ...
        StoppedState: QAudio = ...
        IdleState: QAudio = ...

    class Error(enum.Enum):
        NoError: QAudio = ...
        OpenError: QAudio = ...
        IOError: QAudio = ...
        UnderrunError: QAudio = ...
        FatalError: QAudio = ...

    def convertVolume(
        self, volume: float, from_: "QAudio.VolumeScale", to: "QAudio.VolumeScale"
    ) -> float:
        """
        https://doc.qt.io/qt-6/qaudio.html#convertVolume

        **float QAudio::convertVolume(float volume , QAudio::VolumeScale from ,
        QAudio::VolumeScale to )**

        Converts an audio **volume** **from** a volume scale **to** another, and
        returns the result.

        Depending on the context, different scales are used to represent audio
        volume. All Qt Multimedia classes that have an audio volume use a linear
        scale, the reason is that the loudness of a speaker is controlled by
        modulating its voltage on a linear scale. The human ear on the other
        hand, perceives loudness in a logarithmic way. Using a logarithmic scale
        for volume controls is therefore appropriate in most applications. The
        decibel scale is logarithmic by nature and is commonly used to define
        sound levels, it is usually used for UI volume controls in professional
        audio applications. The cubic scale is a computationally cheap
        approximation of a logarithmic scale, it provides more control over
        lower volume levels.

        The following example shows how to convert the volume value from a
        slider control before passing it to a **QMediaPlayer** . As a result,
        the perceived increase in volume is the same when increasing the volume
        slider from 20 to 30 as it is from 50 to 60:

        void applyVolume(int volumeSliderValue)
            {
                //
        volumeSliderValue is in the range [0..100]

                **qreal**
        linearVolume = QAudio::convertVolume(volumeSliderValue / **qreal**
        (100.0),
        QAudio::LogarithmicVolumeScale,
        QAudio::LinearVolumeScale);

                player.setVolume(**qRound**
        (linearVolume * 100));
            }

        **See also** **VolumeScale** , **QAudioSink::setVolume** (),
        **QAudioSource::setVolume** (), and **QSoundEffect::setVolume** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore


class QQmlPropertyMap(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qqmlpropertymap.html

    **Detailed Description**

    QQmlPropertyMap provides a convenient way to expose domain data to the UI
    layer. The following example shows how you might declare data in C++ and
    then access it in QML.

    In the C++ file:

    // create our data
        **QQmlPropertyMap**  ownerData;
    ownerData.insert("name", **QVariant** (**QString** ("John Smith")));
    ownerData.insert("phone", **QVariant** (**QString** ("555-5555")));
    // expose it to the UI layer
        **QQuickView**  view;
        **QQmlContext**
    *ctxt = view.rootContext();
        ctxt->setContextProperty("owner",
    &ownerData);

        view.setSource(**QUrl** ::fromLocalFile("main.qml"));
    view.show();

    Then, in `main.qml`:

    Text { text: owner.name + " " + owner.phone }

    The binding is dynamic - whenever a key's value is updated, anything bound
    to that key will be updated as well.

    To detect value changes made in the UI layer you can connect to the
    **valueChanged** () signal. However, note that **valueChanged** () is
    **NOT** emitted when changes are made by calling **insert** () or **clear**
    () - it is only emitted when a value is updated from QML.

    **Note:** It is not possible to remove keys from the map; once a key has
    been added, you can only modify or clear its associated value.

    **Note:** When deriving a class from QQmlPropertyMap, use the **protected
    two-argument constructor**  which ensures that the class is correctly
    registered with the Qt **Meta-Object System** .

    **Note:** The **QMetaObject**  of a QQmlPropertyMap is dynamically generated
    and modified. Operations on that meta object are not thread safe, so
    applications need to take care to explicitly synchronize access to the meta
    object.
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qqmlpropertymap.html#QQmlPropertyMap

        **QQmlPropertyMap::QQmlPropertyMap(QObject * parent = nullptr)**

        Constructs a bindable map with parent object **parent**.
        """
        ...

    def updateValue(self, key: str, input: typing.Any) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qqmlpropertymap.html#updateValue

        **[virtual protected] QVariant QQmlPropertyMap::updateValue(const
        QString & key , const QVariant & input )**

        Returns the new value to be stored for the key **key**. This function is
        provided to intercept updates to a property from QML, where the value
        provided from QML is **input**.

        Override this function to manipulate the property value as it is
        updated. Note that this function is only invoked when the value is
        updated from QML.
        """
        ...

    def __getitem__(self, key: str) -> typing.Any:
        ...

    def contains(self, key: str) -> bool:
        """
        https://doc.qt.io/qt-6/qqmlpropertymap.html#contains

        **bool QQmlPropertyMap::contains(const QString & key ) const**

        Returns true if the map contains **key**.

        **See also** **size** ().
        """
        ...

    def isEmpty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qqmlpropertymap.html#isEmpty

        **bool QQmlPropertyMap::isEmpty() const**

        Returns true if the map contains no keys; otherwise returns false.

        **See also** **size** ().
        """
        ...

    def __len__(self) -> int:
        ...

    def size(self) -> int:
        """
        https://doc.qt.io/qt-6/qqmlpropertymap.html#size

        **int QQmlPropertyMap::size() const**

        Returns the number of keys in the map.

        **See also** **isEmpty** () and **count** ().
        """
        ...

    def count(self) -> int:
        """
        https://doc.qt.io/qt-6/qqmlpropertymap.html#count

        **int QQmlPropertyMap::count() const**

        This is an overloaded function.

        Same as **size** ().
        """
        ...

    def keys(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qqmlpropertymap.html#keys

        **[invokable] QStringList QQmlPropertyMap::keys() const**

        Returns the list of keys.

        Keys that have been cleared will still appear in this list, even though
        their associated values are invalid QVariants.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def clear(self, key: str) -> None:
        """
        https://doc.qt.io/qt-6/qqmlpropertymap.html#clear

        **void QQmlPropertyMap::clear(const QString & key )**

        Clears the value (if any) associated with **key**.
        """
        ...

    def freeze(self) -> None:
        """
        https://doc.qt.io/qt-6/qqmlpropertymap.html#freeze

        **[since 6.1] void QQmlPropertyMap::freeze()**

        Disallows any further properties to be added to this property map.
        Existing properties can be modified or cleared.

        In turn, an internal cache is turned on for the existing properties,
        which may result in faster access from QML.

        This function was introduced in Qt 6.1.
        """
        ...

    @typing.overload
    def insert(self, values: typing.Dict[str, typing.Any]) -> None:
        """
        https://doc.qt.io/qt-6/qqmlpropertymap.html#insert

        **void QQmlPropertyMap::insert(const QString & key , const QVariant &
        value )**

        Sets the value associated with **key** to **value**.

        If the key doesn't exist, it is automatically created.
        """
        ...

    @typing.overload
    def insert(self, key: str, value: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qqmlpropertymap.html#insert-1

        **[since 6.1] void QQmlPropertyMap::insert(const QVariantHash & values
        )**

        Inserts the **values** into the **QQmlPropertyMap** .

        Keys that don't exist are automatically created.

        This method is substantially faster than calling `insert(key, value)`
        many times in a row.

        This function was introduced in Qt 6.1.
        """
        ...

    def value(self, key: str) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qqmlpropertymap.html#value

        **QVariant QQmlPropertyMap::value(const QString & key ) const**

        Returns the value associated with **key**.

        If no value has been set for this key (or if the value has been
        cleared), an invalid **QVariant**  is returned.
        """
        ...

    @property
    def valueChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qqmlpropertymap.html#valueChanged

        **[signal] void QQmlPropertyMap::valueChanged(const QString & key ,
        const QVariant & value )**

        This signal is emitted whenever one of the values in the map is changed.
        **key** is the key corresponding to the **value** that was changed.

        **Note:** valueChanged() is **NOT** emitted when changes are made by
        calling **insert** () or **clear** () - it is only emitted when a value
        is updated from QML.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QListWidget(QListView):
    """
    https://doc.qt.io/qt-6/qlistwidget.html

    **Detailed Description**

    ![](images/windows-listview.png)

    QListWidget is a convenience class that provides a list view similar to the
    one supplied by **QListView** , but with a classic item-based interface for
    adding and removing items. QListWidget uses an internal model to manage each
    **QListWidgetItem**  in the list.

    For a more flexible list view widget, use the **QListView**  class with a
    standard model.

    List widgets are constructed in the same way as other widgets:

    QListWidget *listWidget = new QListWidget(this);

    The **selectionMode** () of a list widget determines how many of the items
    in the list can be selected at the same time, and whether complex selections
    of items can be created. This can be set with the **setSelectionMode** ()
    function.

    There are two ways to add items to the list: they can be constructed with
    the list widget as their parent widget, or they can be constructed with no
    parent widget and added to the list later. If a list widget already exists
    when the items are constructed, the first method is easier to use:

    new **QListWidgetItem** (tr("Oak"), listWidget);
            new
    **QListWidgetItem** (tr("Fir"), listWidget);
            new **QListWidgetItem**
    (tr("Pine"), listWidget);

    If you need to insert a new item into the list at a particular position,
    then it should be constructed without a parent widget. The **insertItem** ()
    function should then be used to place it within the list. The list widget
    will take ownership of the item.

    **QListWidgetItem**  *newItem = new **QListWidgetItem** ;
    newItem->setText(itemText);
            listWidget->insertItem(row, newItem);

    For multiple items, **insertItems** () can be used instead. The number of
    items in the list is found with the **count** () function. To remove items
    from the list, use **takeItem** ().

    The current item in the list can be found with **currentItem** (), and
    changed with **setCurrentItem** (). The user can also change the current
    item by navigating with the keyboard or clicking on a different item. When
    the current item changes, the **currentItemChanged** () signal is emitted
    with the new current item and the item that was previously current.

    **See also** **QListWidgetItem** , **QListView** , **QTreeView** ,
    **Model/View Programming** , and **Tab Dialog Example** .
    """

    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#QListWidget

        **QListWidget::QListWidget(QWidget * parent = nullptr)**

        Constructs an empty QListWidget with the given **parent**.
        """
        ...

    def isPersistentEditorOpen(self, item: QListWidgetItem) -> bool:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#isPersistentEditorOpen

        **[since 5.10] bool QListWidget::isPersistentEditorOpen(QListWidgetItem
        * item ) const**

        Returns whether a persistent editor is open for item **item**.

        This function was introduced in Qt 5.10.

        **See also** **openPersistentEditor** () and **closePersistentEditor**
        ().
        """
        ...

    def setSelectionModel(self, selectionModel: QtCore.QItemSelectionModel) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#setSelectionModel

        **[override virtual] void
        QListWidget::setSelectionModel(QItemSelectionModel * selectionModel )**

        Reimplements: **QAbstractItemView::setSelectionModel**
        (QItemSelectionModel *selectionModel).
        """
        ...

    def removeItemWidget(self, aItem: QListWidgetItem) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#removeItemWidget

        **void QListWidget::removeItemWidget(QListWidgetItem * item )**

        Removes the widget set on the given **item**.

        To remove an item (row) from the list entirely, either delete the item
        or use **takeItem** ().

        **See also** **itemWidget** () and **setItemWidget** ().
        """
        ...

    def isSortingEnabled(self) -> bool:
        ...

    def setSortingEnabled(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#sortingEnabled-prop

        **sortingEnabled : bool**

        This property holds whether sorting is enabled

        If this property is `true`, sorting is enabled for the list; if the
        property is false, sorting is not enabled.

        The default value is false.

        **Access functions:**

        bool **isSortingEnabled** () const
        void **setSortingEnabled** (bool
        **enable** )

        **Member Function Documentation**
        """
        ...

    def itemFromIndex(self, index: QtCore.QModelIndex) -> QListWidgetItem:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#itemFromIndex

        **QListWidgetItem *QListWidget::itemFromIndex(const QModelIndex & index
        ) const**

        Returns a pointer to the **QListWidgetItem**  associated with the given
        **index**.
        """
        ...

    def indexFromItem(self, item: QListWidgetItem) -> QtCore.QModelIndex:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#indexFromItem

        **QModelIndex QListWidget::indexFromItem(const QListWidgetItem * item )
        const**

        Returns the **QModelIndex**  associated with the given **item**.

        **Note:** In Qt versions prior to 5.10, this function took a non-`const`
        **item**.
        """
        ...

    def items(self, data: QtCore.QMimeData) -> typing.List[QListWidgetItem]:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#items

        **QList<QListWidgetItem *> QListWidget::items(const QMimeData * data )
        const**

        Returns a list of pointers to the items contained in the **data**
        object. If the object was not created by a **QListWidget**  in the same
        process, the list is empty.
        """
        ...

    def dropEvent(self, event: QtGui.QDropEvent) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#dropEvent

        **[override virtual protected] void QListWidget::dropEvent(QDropEvent *
        event )**

        Reimplements: **QListView::dropEvent** (QDropEvent *event).
        """
        ...

    def event(self, e: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#event

        **[override virtual protected] bool QListWidget::event(QEvent * e )**

        Reimplements: **QListView::event** (QEvent *e).
        """
        ...

    def supportedDropActions(self) -> QtCore.Qt.DropAction:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#supportedDropActions

        **[virtual protected] Qt::DropActions
        QListWidget::supportedDropActions() const**

        Returns the drop actions supported by this view.

        **See also** **Qt::DropActions** .
        """
        ...

    def dropMimeData(
        self, index: int, data: QtCore.QMimeData, action: QtCore.Qt.DropAction
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#dropMimeData

        **[virtual protected] bool QListWidget::dropMimeData(int index , const
        QMimeData * data , Qt::DropAction action )**

        Handles **data** supplied by an external drag and drop operation that
        ended with the given **action** in the given **index**. Returns `true`
        if **data** and **action** can be handled by the model; otherwise
        returns `false`.

        **See also** **supportedDropActions** ().
        """
        ...

    def mimeData(self, items: typing.Iterable[QListWidgetItem]) -> QtCore.QMimeData:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#mimeData

        **[virtual protected] QMimeData *QListWidget::mimeData(const
        QList<QListWidgetItem *> & items ) const**

        Returns an object that contains a serialized description of the
        specified **items**. The format used to describe the items is obtained
        from the **mimeTypes** () function.

        If the list of items is empty, `nullptr` is returned instead of a
        serialized empty list.
        """
        ...

    def mimeTypes(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#mimeTypes

        **[virtual protected] QStringList QListWidget::mimeTypes() const**

        Returns a list of MIME types that can be used to describe a list of
        listwidget items.

        **See also** **mimeData** ().
        """
        ...

    def scrollToItem(
        self, item: QListWidgetItem, hint: QAbstractItemView.ScrollHint = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#scrollToItem

        **[slot] void QListWidget::scrollToItem(const QListWidgetItem * item ,
        QAbstractItemView::ScrollHint hint = EnsureVisible)**

        Scrolls the view if necessary to ensure that the **item** is visible.

        **hint** specifies where the **item** should be located after the
        operation.
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#clear

        **[slot] void QListWidget::clear()**

        Removes all items and selections in the view.

        **Warning:** All items will be permanently deleted.
        """
        ...

    def findItems(
        self, text: str, flags: QtCore.Qt.MatchFlag
    ) -> typing.List[QListWidgetItem]:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#findItems

        **QList<QListWidgetItem *> QListWidget::findItems(const QString & text ,
        Qt::MatchFlags flags ) const**

        Finds items with the text that matches the string **text** using the
        given **flags**.
        """
        ...

    def selectedItems(self) -> typing.List[QListWidgetItem]:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#selectedItems

        **QList<QListWidgetItem *> QListWidget::selectedItems() const**

        Returns a list of all selected items in the list widget.
        """
        ...

    def closePersistentEditor(self, item: QListWidgetItem) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#closePersistentEditor

        **void QListWidget::closePersistentEditor(QListWidgetItem * item )**

        Closes the persistent editor for the given **item**.

        **See also** **openPersistentEditor** () and **isPersistentEditorOpen**
        ().
        """
        ...

    def openPersistentEditor(self, item: QListWidgetItem) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#openPersistentEditor

        **void QListWidget::openPersistentEditor(QListWidgetItem * item )**

        Opens an editor for the given **item**. The editor remains open after
        editing.

        **See also** **closePersistentEditor** () and **isPersistentEditorOpen**
        ().
        """
        ...

    def editItem(self, item: QListWidgetItem) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#editItem

        **void QListWidget::editItem(QListWidgetItem * item )**

        Starts editing the **item** if it is editable.
        """
        ...

    def sortItems(self, order: QtCore.Qt.SortOrder = ...) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#sortItems

        **void QListWidget::sortItems(Qt::SortOrder order =
        Qt::AscendingOrder)**

        Sorts all the items in the list widget according to the specified
        **order**.
        """
        ...

    def visualItemRect(self, item: QListWidgetItem) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#visualItemRect

        **QRect QListWidget::visualItemRect(const QListWidgetItem * item )
        const**

        Returns the rectangle on the viewport occupied by the item at **item**.
        """
        ...

    def setItemWidget(self, item: QListWidgetItem, widget: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#setItemWidget

        **void QListWidget::setItemWidget(QListWidgetItem * item , QWidget *
        widget )**

        Sets the **widget** to be displayed in the given **item**.

        This function should only be used to display static content in the place
        of a list widget item. If you want to display custom dynamic content or
        implement a custom editor widget, use **QListView**  and subclass
        **QStyledItemDelegate**  instead.

        **See also** **itemWidget** (), **removeItemWidget** (), and **Delegate
        Classes** .
        """
        ...

    def itemWidget(self, item: QListWidgetItem) -> QWidget:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#itemWidget

        **QWidget *QListWidget::itemWidget(QListWidgetItem * item ) const**

        Returns the widget displayed in the given **item**.

        **See also** **setItemWidget** () and **removeItemWidget** ().
        """
        ...

    @typing.overload
    def itemAt(self, p: QtCore.QPoint) -> QListWidgetItem:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#itemAt

        **QListWidgetItem *QListWidget::itemAt(const QPoint & p ) const**

        Returns a pointer to the item at the coordinates **p**. The coordinates
        are relative to the list widget's **viewport** ().
        """
        ...

    @typing.overload
    def itemAt(self, ax: int, ay: int) -> QListWidgetItem:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#itemAt-1

        **QListWidgetItem *QListWidget::itemAt(int x , int y ) const**

        This is an overloaded function.

        Returns a pointer to the item at the coordinates ( **x** , **y** ). The
        coordinates are relative to the list widget's **viewport** ().
        """
        ...

    @typing.overload
    def setCurrentRow(self, row: int) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#setCurrentRow-1

        **void QListWidget::setCurrentRow(int row ,
        QItemSelectionModel::SelectionFlags command )**

        Sets the current row to be the given **row** , using the given
        **command** ,

        **Note:** Setter function for property **currentRow** .
        """
        ...

    @typing.overload
    def setCurrentRow(
        self, row: int, command: QtCore.QItemSelectionModel.SelectionFlag
    ) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#currentRow-prop

        **currentRow : int**

        This property holds the row of the current item.

        Depending on the current selection mode, the row may also be selected.

        **Access functions:**

        int **currentRow** () const
        void **setCurrentRow** (int **row** )
        void ****setCurrentRow** ** (int **row** ,
        QItemSelectionModel::SelectionFlags **command** )

        **Notifier signal:**

        void ****currentRowChanged** ** (int **currentRow** )
        """
        ...

    def currentRow(self) -> int:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#currentRow-prop

        **currentRow : int**

        This property holds the row of the current item.

        Depending on the current selection mode, the row may also be selected.

        **Access functions:**

        int **currentRow** () const
        void **setCurrentRow** (int **row** )
        void ****setCurrentRow** ** (int **row** ,
        QItemSelectionModel::SelectionFlags **command** )

        **Notifier signal:**

        void ****currentRowChanged** ** (int **currentRow** )
        """
        ...

    @typing.overload
    def setCurrentItem(self, item: QListWidgetItem) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#setCurrentItem

        **void QListWidget::setCurrentItem(QListWidgetItem * item )**

        Sets the current item to **item**.

        Unless the selection mode is **NoSelection** , the item is also
        selected.

        **See also** **currentItem** ().
        """
        ...

    @typing.overload
    def setCurrentItem(
        self, item: QListWidgetItem, command: QtCore.QItemSelectionModel.SelectionFlag
    ) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#setCurrentItem-1

        **void QListWidget::setCurrentItem(QListWidgetItem * item ,
        QItemSelectionModel::SelectionFlags command )**

        Set the current item to **item** , using the given **command**.
        """
        ...

    def currentItem(self) -> QListWidgetItem:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#currentItem

        **QListWidgetItem *QListWidget::currentItem() const**

        Returns the current item.

        **See also** **setCurrentItem** ().
        """
        ...

    def __len__(self) -> int:
        ...

    def count(self) -> int:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#count-prop

        **[read-only] count : const int**

        This property holds the number of items in the list including any hidden
        items.

        **Access functions:**

        int **count** () const
        """
        ...

    def takeItem(self, row: int) -> QListWidgetItem:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#takeItem

        **QListWidgetItem *QListWidget::takeItem(int row )**

        Removes and returns the item from the given **row** in the list widget;
        otherwise returns `nullptr`.

        Items removed from a list widget will not be managed by Qt, and will
        need to be deleted manually.

        **See also** **insertItem** () and **addItem** ().
        """
        ...

    def addItems(self, labels: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#addItems

        **void QListWidget::addItems(const QStringList & labels )**

        Inserts items with the text **labels** at the end of the list widget.

        **See also** **insertItems** ().
        """
        ...

    @typing.overload
    def addItem(self, aitem: QListWidgetItem) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#addItem

        **void QListWidget::addItem(const QString & label )**

        Inserts an item with the text **label** at the end of the list widget.
        """
        ...

    @typing.overload
    def addItem(self, label: str) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#addItem-1

        **void QListWidget::addItem(QListWidgetItem * item )**

        Inserts the **item** at the end of the list widget.

        **Warning:** A **QListWidgetItem**  can only be added to a
        **QListWidget**  once. Adding the same **QListWidgetItem**  multiple
        times to a **QListWidget**  will result in undefined behavior.

        **See also** **insertItem** ().
        """
        ...

    def insertItems(self, row: int, labels: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#insertItems

        **void QListWidget::insertItems(int row , const QStringList & labels )**

        Inserts items from the list of **labels** into the list, starting at the
        given **row**.

        **See also** **insertItem** () and **addItem** ().
        """
        ...

    @typing.overload
    def insertItem(self, row: int, item: QListWidgetItem) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#insertItem

        **void QListWidget::insertItem(int row , QListWidgetItem * item )**

        Inserts the **item** at the position in the list given by **row**.

        **See also** **addItem** ().
        """
        ...

    @typing.overload
    def insertItem(self, row: int, label: str) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#insertItem-1

        **void QListWidget::insertItem(int row , const QString & label )**

        Inserts an item with the text **label** in the list widget at the
        position given by **row**.

        **See also** **addItem** ().
        """
        ...

    def row(self, item: QListWidgetItem) -> int:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#row

        **int QListWidget::row(const QListWidgetItem * item ) const**

        Returns the row containing the given **item**.

        **See also** **item** ().
        """
        ...

    def item(self, row: int) -> QListWidgetItem:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#item

        **QListWidgetItem *QListWidget::item(int row ) const**

        Returns the item that occupies the given **row** in the list if one has
        been set; otherwise returns `nullptr`.

        **See also** **row** ().
        """
        ...

    @property
    def currentItemChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#currentItemChanged

        **[signal] void QListWidget::currentItemChanged(QListWidgetItem *
        current , QListWidgetItem * previous )**

        This signal is emitted whenever the current item changes.

        **previous** is the item that previously had the focus; **current** is
        the new current item.
        """
        ...

    @property
    def currentRowChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#currentRowChanged

        **[signal] void QListWidget::currentRowChanged(int currentRow )**

        This signal is emitted whenever the current item changes.

        **currentRow** is the row of the current item. If there is no current
        item, the **currentRow** is -1.

        **Note:** Notifier signal for property **currentRow** .
        """
        ...

    @property
    def currentTextChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#currentTextChanged

        **[signal] void QListWidget::currentTextChanged(const QString &
        currentText )**

        This signal is emitted whenever the current item changes.

        **currentText** is the text data in the current item. If there is no
        current item, the **currentText** is invalid.
        """
        ...

    @property
    def itemActivated(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#itemActivated

        **[signal] void QListWidget::itemActivated(QListWidgetItem * item )**

        This signal is emitted when the **item** is activated. The **item** is
        activated when the user clicks or double clicks on it, depending on the
        system configuration. It is also activated when the user presses the
        activation key (on Windows and X11 this is the **Return** key, on Mac OS
        X it is **Command+O** ).
        """
        ...

    @property
    def itemChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#itemChanged

        **[signal] void QListWidget::itemChanged(QListWidgetItem * item )**

        This signal is emitted whenever the data of **item** has changed.
        """
        ...

    @property
    def itemClicked(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#itemClicked

        **[signal] void QListWidget::itemClicked(QListWidgetItem * item )**

        This signal is emitted with the specified **item** when a mouse button
        is clicked on an item in the widget.

        **See also** **itemPressed** () and **itemDoubleClicked** ().
        """
        ...

    @property
    def itemDoubleClicked(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#itemDoubleClicked

        **[signal] void QListWidget::itemDoubleClicked(QListWidgetItem * item
        )**

        This signal is emitted with the specified **item** when a mouse button
        is double clicked on an item in the widget.

        **See also** **itemClicked** () and **itemPressed** ().
        """
        ...

    @property
    def itemEntered(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#itemEntered

        **[signal] void QListWidget::itemEntered(QListWidgetItem * item )**

        This signal is emitted when the mouse cursor enters an item. The
        **item** is the item entered. This signal is only emitted when
        mouseTracking is turned on, or when a mouse button is pressed while
        moving into an item.

        **See also** **QWidget::setMouseTracking** ().
        """
        ...

    @property
    def itemPressed(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#itemPressed

        **[signal] void QListWidget::itemPressed(QListWidgetItem * item )**

        This signal is emitted with the specified **item** when a mouse button
        is pressed on an item in the widget.

        **See also** **itemClicked** () and **itemDoubleClicked** ().
        """
        ...

    @property
    def itemSelectionChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qlistwidget.html#itemSelectionChanged

        **[signal] void QListWidget::itemSelectionChanged()**

        This signal is emitted whenever the selection changes.

        **See also** **selectedItems** (), **QListWidgetItem::isSelected** (),
        and **currentItemChanged** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtQuick import *


class QSGRectangleNode(QSGGeometryNode):
    """
    https://doc.qt.io/qt-6/qsgrectanglenode.html

    **Detailed Description**
    """

    def color(self) -> QtGui.QColor:
        """
        https://doc.qt.io/qt-6/qsgrectanglenode.html#color

        **[pure virtual] QColor QSGRectangleNode::color() const**

        Returns the color of this rectangle.

        **See also** **setColor** ().
        """
        ...

    def setColor(
        self, color: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor, int]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsgrectanglenode.html#setColor

        **[pure virtual] void QSGRectangleNode::setColor(const QColor & color
        )**

        Sets the color of this rectangle to **color**. The default color will be
        white.

        **See also** **color** ().
        """
        ...

    def rect(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qsgrectanglenode.html#rect

        **[pure virtual] QRectF QSGRectangleNode::rect() const**

        Returns the rectangle that this rect node covers.

        **See also** **setRect** ().
        """
        ...

    @typing.overload
    def setRect(self, rect: QtCore.QRectF) -> None:
        """
        https://doc.qt.io/qt-6/qsgrectanglenode.html#setRect

        **[pure virtual] void QSGRectangleNode::setRect(const QRectF & rect )**

        Sets the rectangle of this rect node to **rect**.

        **See also** **rect** ().
        """
        ...

    @typing.overload
    def setRect(self, x: float, y: float, w: float, h: float) -> None:
        """
        https://doc.qt.io/qt-6/qsgrectanglenode.html#setRect-1

        **void QSGRectangleNode::setRect(qreal x , qreal y , qreal w , qreal h
        )**

        This is an overloaded function.

        Sets the rectangle of this rect node to begin at ( **x** , **y** ) and
        have width **w** and height **h**.
        """
        ...
